"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QSocketNotifier(QObject):
    """
    https://doc.qt.io/qt-6/qsocketnotifier.html

    **Detailed Description**

    The QSocketNotifier makes it possible to integrate Qt's event loop with
    other event loops based on file descriptors. File descriptor action is
    detected in Qt's main event loop (**QCoreApplication::exec** ()).

    Once you have opened a device using a low-level (usually platform-specific)
    API, you can create a socket notifier to monitor the file descriptor. If the
    descriptor is passed to the notifier's constructor, the socket notifier is
    enabled by default, i.e. it emits the **activated** () signal whenever a
    socket event corresponding to its type occurs. Connect the **activated** ()
    signal to the slot you want to be called when an event corresponding to your
    socket notifier's type occurs.

    You can create a socket notifier with no descriptor assigned. In this case,
    you should call the **setSocket** () function after the descriptor has been
    obtained.

    There are three types of socket notifiers: read, write, and exception. The
    type is described by the **Type**  enum, and must be specified when
    constructing the socket notifier. After construction it can be determined
    using the **type** () function. Note that if you need to monitor both reads
    and writes for the same file descriptor, you must create two socket
    notifiers. Note also that it is not possible to install two socket notifiers
    of the same type (**Read** , **Write** , **Exception** ) on the same socket.

    The **setEnabled** () function allows you to disable as well as enable the
    socket notifier. It is generally advisable to explicitly enable or disable
    the socket notifier, especially for write notifiers. A disabled notifier
    ignores socket events (the same effect as not creating the socket notifier).
    Use the **isEnabled** () function to determine the notifier's current
    status.

    Finally, you can use the **socket** () function to retrieve the socket
    identifier. Although the class is called QSocketNotifier, it is normally
    used for other types of devices than sockets. **QTcpSocket**  and
    **QUdpSocket**  provide notification through signals, so there is normally
    no need to use a QSocketNotifier on them.

    **See also** **QFile** , **QProcess** , **QTcpSocket** , and **QUdpSocket**
    .
    """

    class Type(enum.Enum):
        Read: QSocketNotifier = ...
        Write: QSocketNotifier = ...
        Exception: QSocketNotifier = ...

    @typing.overload
    def __init__(
        self, a0: "QSocketNotifier.Type", parent: typing.Optional[QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsocketnotifier.html#QSocketNotifier

        **[since 6.1] QSocketNotifier::QSocketNotifier(QSocketNotifier::Type
        type , QObject * parent = nullptr)**

        Constructs a socket notifier with the given **type** that has no
        descriptor assigned. The **parent** argument is passed to **QObject** 's
        constructor.

        Call the **setSocket** () function to set the descriptor for monitoring.

        This function was introduced in Qt 6.1.

        **See also** **setSocket** (), **isValid** (), and **isEnabled** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        socket: PyQt6.sip.voidptr,
        a1: "QSocketNotifier.Type",
        parent: typing.Optional[QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsocketnotifier.html#QSocketNotifier-1

        **QSocketNotifier::QSocketNotifier(qintptr socket ,
        QSocketNotifier::Type type , QObject * parent = nullptr)**

        Constructs a socket notifier with the given **parent**. It enables the
        **socket** , and watches for events of the given **type**.

        It is generally advisable to explicitly enable or disable the socket
        notifier, especially for write notifiers.

        **Note for Windows users:** The socket passed to QSocketNotifier will
        become non-blocking, even if it was created as a blocking socket.

        **See also** **setEnabled** () and **isEnabled** ().
        """
        ...

    def event(self, a0: QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qsocketnotifier.html#event

        **[override virtual protected] bool QSocketNotifier::event(QEvent * e
        )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsocketnotifier.html#isValid

        **[since 6.1] bool QSocketNotifier::isValid() const**

        Returns `true` if the notifier is valid (that is, it has a descriptor
        assigned); otherwise returns `false`.

        This function was introduced in Qt 6.1.

        **See also** **setSocket** ().
        """
        ...

    def setSocket(self, socket: PyQt6.sip.voidptr) -> None:
        """
        https://doc.qt.io/qt-6/qsocketnotifier.html#setSocket

        **[since 6.1] void QSocketNotifier::setSocket(qintptr socket )**

        Assigns the **socket** to this notifier.

        **Note:** The notifier will be disabled as a side effect and needs to be
        re-enabled.

        This function was introduced in Qt 6.1.

        **See also** **socket** (), **setEnabled** (), and **isValid** ().
        """
        ...

    def setEnabled(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsocketnotifier.html#setEnabled

        **[slot] void QSocketNotifier::setEnabled(bool enable )**

        If **enable** is true, the notifier is enabled; otherwise the notifier
        is disabled.

        When the notifier is enabled, it emits the **activated** () signal
        whenever a socket event corresponding to its **type**  occurs. When it
        is disabled, it ignores socket events (the same effect as not creating
        the socket notifier).

        Write notifiers should normally be disabled immediately after the
        **activated** () signal has been emitted

        **See also** **isEnabled** () and **activated** ().
        """
        ...

    def isEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsocketnotifier.html#isEnabled

        **bool QSocketNotifier::isEnabled() const**

        Returns `true` if the notifier is enabled; otherwise returns `false`.

        **See also** **setEnabled** ().
        """
        ...

    def type(self) -> "QSocketNotifier.Type":
        """
        https://doc.qt.io/qt-6/qsocketnotifier.html#type

        **QSocketNotifier::Type QSocketNotifier::type() const**

        Returns the socket event type specified to the constructor.

        **See also** **socket** ().
        """
        ...

    def socket(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qsocketnotifier.html#socket

        **qintptr QSocketNotifier::socket() const**

        Returns the socket identifier assigned to this object.

        **See also** **setSocket** (), **isValid** (), and **type** ().
        """
        ...

    @property
    def activated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsocketnotifier.html#activated

        **[private signal, since 5.15] void
        QSocketNotifier::activated(QSocketDescriptor socket ,
        QSocketNotifier::Type type )**

        This signal is emitted whenever the socket notifier is enabled and a
        socket event corresponding to its **type** occurs.

        The socket identifier is passed in the **socket** parameter.

        **Note:** This is a private signal. It can be used in signal connections
        but cannot be emitted by the user.

        **Note:** Signal **activated** is overloaded in this class. To connect
        to this signal by using the function pointer syntax, Qt provides a
        convenient helper for obtaining the function pointer as shown in this
        example:

        connect(socketNotifier, QOverload<QSocketDescriptor, **QSocketNotifier**
        ::Type>::of(&**QSocketNotifier** ::activated),
        [=](QSocketDescriptor socket, **QSocketNotifier** ::Type type){ /* ...
        */ });

        This function was introduced in Qt 5.15.

        **See also** **type** () and **socket** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QWebChannelAbstractTransport(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qwebchannelabstracttransport.html

    **Detailed Description**

    Users of the **QWebChannel**  must implement this interface and connect
    instances of it to the **QWebChannel**  server for every client that should
    be connected to the **QWebChannel** . The **Qt WebChannel Standalone
    Example**  shows how this can be done using **Qt WebSockets** .

    **Note:** The JSON message protocol is considered internal and might change
    over time.

    **See also** **Qt WebChannel Standalone Example** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qwebchannelabstracttransport.html#QWebChannelAbst
        ractTransport

        **QWebChannelAbstractTransport::QWebChannelAbstractTransport(QObject *
        parent = nullptr)**

        Constructs a transport object with the given **parent**.
        """
        ...

    def sendMessage(
        self,
        message: typing.Dict[
            str,
            typing.Union[
                QtCore.QJsonValue,
                QtCore.QJsonValue.Type,
                typing.Iterable[QtCore.QJsonValue],
                bool,
                int,
                float,
                None,
                str,
            ],
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qwebchannelabstracttransport.html#sendMessage

        **[pure virtual slot] void
        QWebChannelAbstractTransport::sendMessage(const QJsonObject & message
        )**

        Sends a JSON **message** to the remote client. An implementation would
        serialize the message and transmit it to the remote JavaScript client.
        """
        ...

    @property
    def messageReceived(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwebchannelabstracttransport.html#messageReceived

        **[signal] void QWebChannelAbstractTransport::messageReceived(const
        QJsonObject & message , QWebChannelAbstractTransport * transport )**

        This signal must be emitted when a new JSON **message** was received
        from the remote client. The **transport** argument should be set to this
        transport object.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QAction(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qaction.html

    **Detailed Description**

    In applications many common commands can be invoked via menus, toolbar
    buttons, and keyboard shortcuts. Since the user expects each command to be
    performed in the same way, regardless of the user interface used, it is
    useful to represent each command as an **action**.

    Actions can be added to menus and toolbars, and will automatically keep them
    in sync. For example, in a word processor, if the user presses a Bold
    toolbar button, the Bold menu item will automatically be checked.

    A QAction may contain an icon, menu text, a shortcut, status text, "What's
    This?" text, and a tooltip. Most of these can be set in the constructor.
    They can also be set independently with **setIcon** (), **setText** (),
    **setIconText** (), **setShortcut** (), **setStatusTip** (),
    **setWhatsThis** (), and **setToolTip** (). For menu items, it is possible
    to set an individual font with **setFont** ().

    We recommend that actions are created as children of the window they are
    used in. In most cases actions will be children of the application's main
    window.

    **QAction in widget applications**

    Once a QAction has been created, it should be added to the relevant menu and
    toolbar, then connected to the slot which will perform the action. For
    example:

    const **QIcon**  openIcon = **QIcon** ::fromTheme("document-open", **QIcon**
    (":/images/open.png"));
            **QAction**  *openAct = new **QAction**
    (openIcon, tr("&Open..."), this);
    openAct->setShortcuts(**QKeySequence** ::Open);
    openAct->setStatusTip(tr("Open an existing file"));
            connect(openAct,
    &**QAction** ::triggered, this, &MainWindow::open);
    fileMenu->addAction(openAct);
            fileToolBar->addAction(openAct);

    Actions are added to widgets using **QWidget::addAction** () or
    **QGraphicsWidget::addAction** (). Note that an action must be added to a
    widget before it can be used. This is also true when the shortcut should be
    global (i.e., **Qt::ApplicationShortcut**  as **Qt::ShortcutContext** ).

    Actions can be created as independent objects. But they may also be created
    during the construction of menus. The **QMenu**  class contains convenience
    functions for creating actions suitable for use as menu items.

    **See also** **QMenu** , **QToolBar** , and **Qt Widgets - Application
    Example** .
    """

    class Priority(enum.Enum):
        LowPriority: QAction = ...
        NormalPriority: QAction = ...
        HighPriority: QAction = ...

    class MenuRole(enum.Enum):
        NoRole: QAction = ...
        TextHeuristicRole: QAction = ...
        ApplicationSpecificRole: QAction = ...
        AboutQtRole: QAction = ...
        AboutRole: QAction = ...
        PreferencesRole: QAction = ...
        QuitRole: QAction = ...

    class ActionEvent(enum.Enum):
        Trigger: QAction = ...
        Hover: QAction = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#QAction

        **QAction::QAction(QObject * parent = nullptr)**

        Constructs an action with **parent**. If **parent** is an action group
        the action will be automatically inserted into the group.

        **Note:** The **parent** argument is optional since Qt 5.7.
        """
        ...

    @typing.overload
    def __init__(
        self, text: str, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#QAction-1

        **QAction::QAction(const QString & text , QObject * parent = nullptr)**

        Constructs an action with some **text** and **parent**. If **parent** is
        an action group the action will be automatically inserted into the
        group.

        The action uses a stripped version of **text** (e.g. "&Menu Option..."
        becomes "Menu Option") as descriptive text for tool buttons. You can
        override this by setting a specific description with **setText** (). The
        same text will be used for tooltips unless you specify a different text
        using **setToolTip** ().
        """
        ...

    @typing.overload
    def __init__(
        self, icon: "QIcon", text: str, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#QAction-2

        **QAction::QAction(const QIcon & icon , const QString & text , QObject *
        parent = nullptr)**

        Constructs an action with an **icon** and some **text** and **parent**.
        If **parent** is an action group the action will be automatically
        inserted into the group.

        The action uses a stripped version of **text** (e.g. "&Menu Option..."
        becomes "Menu Option") as descriptive text for tool buttons. You can
        override this by setting a specific description with **setText** (). The
        same text will be used for tooltips unless you specify a different text
        using **setToolTip** ().
        """
        ...

    def resetEnabled(self) -> None:
        ...

    def associatedObjects(self) -> typing.List[QtCore.QObject]:
        """
        https://doc.qt.io/qt-6/qaction.html#associatedObjects

        **[since 6.0] QList<QObject *> QAction::associatedObjects() const**

        Returns a list of objects this action has been added to.

        This function was introduced in Qt 6.0.

        **See also** **QWidget::addAction** () and
        **QGraphicsWidget::addAction** ().
        """
        ...

    def isShortcutVisibleInContextMenu(self) -> bool:
        ...

    def setShortcutVisibleInContextMenu(self, show: bool) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#shortcutVisibleInContextMenu-prop

        **shortcutVisibleInContextMenu : bool**

        This property holds whether or not an action should show a shortcut in a
        context menu

        In some applications, it may make sense to have actions with shortcuts
        in context menus. If true, the shortcut (if valid) is shown when the
        action is shown via a context menu, when it is false, it is not shown.

        The default is to follow whether the
        **Qt::AA_DontShowShortcutsInContextMenus**  attribute is set for the
        application. Explicitly setting this property overrides the attribute.

        **Access functions:**

        bool **isShortcutVisibleInContextMenu** () const
        void
        **setShortcutVisibleInContextMenu** (bool **show** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **shortcut**  and **QCoreApplication::setAttribute** ().
        """
        ...

    def priority(self) -> "QAction.Priority":
        """
        https://doc.qt.io/qt-6/qaction.html#priority-prop

        **priority : Priority**

        This property holds the actions's priority in the user interface.

        This property can be set to indicate how the action should be
        prioritized in the user interface.

        For instance, when toolbars have the **Qt::ToolButtonTextBesideIcon**
        mode set, then actions with **LowPriority**  will not show the text
        labels.

        **Access functions:**

        QAction::Priority **priority** () const
        void **setPriority**
        (QAction::Priority **priority** )
        """
        ...

    def setPriority(self, priority: "QAction.Priority") -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#priority-prop

        **priority : Priority**

        This property holds the actions's priority in the user interface.

        This property can be set to indicate how the action should be
        prioritized in the user interface.

        For instance, when toolbars have the **Qt::ToolButtonTextBesideIcon**
        mode set, then actions with **LowPriority**  will not show the text
        labels.

        **Access functions:**

        QAction::Priority **priority** () const
        void **setPriority**
        (QAction::Priority **priority** )
        """
        ...

    def isIconVisibleInMenu(self) -> bool:
        ...

    def setIconVisibleInMenu(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#iconVisibleInMenu-prop

        **iconVisibleInMenu : bool**

        This property holds whether or not an action should show an icon in a
        menu

        In some applications, it may make sense to have actions with icons in
        the toolbar, but not in menus. If true, the icon (if valid) is shown in
        the menu, when it is false, it is not shown.

        The default is to follow whether the **Qt::AA_DontShowIconsInMenus**
        attribute is set for the application. Explicitly settings this property
        overrides the presence (or absence) of the attribute.

        For example:

        **QApplication**  app(argc, argv);
        app.setAttribute(Qt::AA_DontShowIconsInMenus);  // Icons are *no longer
        shown* in menus
            // ...
            **QAction**  *myAction = new **QAction**
        ();
            // ...
            myAction->setIcon(SomeIcon);
        myAction->setIconVisibleInMenu(true);   // Icon *will* be shown in menus
        for *this* action.

        **Access functions:**

        bool **isIconVisibleInMenu** () const
        void **setIconVisibleInMenu**
        (bool **visible** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **icon**  and **QCoreApplication::setAttribute** ().
        """
        ...

    def menuRole(self) -> "QAction.MenuRole":
        """
        https://doc.qt.io/qt-6/qaction.html#menuRole-prop

        **menuRole : MenuRole**

        This property holds the action's menu role

        This indicates what role the action serves in the application menu on
        macOS. By default all actions have the **TextHeuristicRole** , which
        means that the action is added based on its text (see **QMenuBar**  for
        more information).

        The menu role can only be changed before the actions are put into the
        menu bar in macOS (usually just before the first application window is
        shown).

        **Access functions:**

        QAction::MenuRole **menuRole** () const
        void **setMenuRole**
        (QAction::MenuRole **menuRole** )

        **Notifier signal:**

        void ****changed** ** ()
        """
        ...

    def setMenuRole(self, menuRole: "QAction.MenuRole") -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#menuRole-prop

        **menuRole : MenuRole**

        This property holds the action's menu role

        This indicates what role the action serves in the application menu on
        macOS. By default all actions have the **TextHeuristicRole** , which
        means that the action is added based on its text (see **QMenuBar**  for
        more information).

        The menu role can only be changed before the actions are put into the
        menu bar in macOS (usually just before the first application window is
        shown).

        **Access functions:**

        QAction::MenuRole **menuRole** () const
        void **setMenuRole**
        (QAction::MenuRole **menuRole** )

        **Notifier signal:**

        void ****changed** ** ()
        """
        ...

    def autoRepeat(self) -> bool:
        """
        https://doc.qt.io/qt-6/qaction.html#autoRepeat-prop

        **autoRepeat : bool**

        This property holds whether the action can auto repeat

        If true, the action will auto repeat when the keyboard shortcut
        combination is held down, provided that keyboard auto repeat is enabled
        on the system. The default value is true.

        **Access functions:**

        bool **autoRepeat** () const
        void **setAutoRepeat** (bool)

        **Notifier signal:**

        void ****changed** ** ()
        """
        ...

    def setAutoRepeat(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#autoRepeat-prop

        **autoRepeat : bool**

        This property holds whether the action can auto repeat

        If true, the action will auto repeat when the keyboard shortcut
        combination is held down, provided that keyboard auto repeat is enabled
        on the system. The default value is true.

        **Access functions:**

        bool **autoRepeat** () const
        void **setAutoRepeat** (bool)

        **Notifier signal:**

        void ****changed** ** ()
        """
        ...

    def shortcuts(self) -> typing.List["QKeySequence"]:
        """
        https://doc.qt.io/qt-6/qaction.html#shortcuts

        **QList<QKeySequence> QAction::shortcuts() const**

        Returns the list of shortcuts, with the primary shortcut as the first
        element of the list.

        **See also** **setShortcuts** ().
        """
        ...

    @typing.overload
    def setShortcuts(
        self,
        shortcuts: typing.Iterable[
            typing.Union["QKeySequence", "QKeySequence.StandardKey", str, int]
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#setShortcuts

        **void QAction::setShortcuts(const QList<QKeySequence> & shortcuts )**

        Sets **shortcuts** as the list of shortcuts that trigger the action. The
        first element of the list is the primary shortcut.

        **See also** **shortcuts** (), **shortcut** , and **setShortcut** ().
        """
        ...

    @typing.overload
    def setShortcuts(self, a0: "QKeySequence.StandardKey") -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#setShortcuts-1

        **void QAction::setShortcuts(QKeySequence::StandardKey key )**

        Sets a platform dependent list of shortcuts based on the **key**. The
        result of calling this function will depend on the currently running
        platform. Note that more than one shortcut can assigned by this action.
        If only the primary shortcut is required, use **setShortcut**  instead.

        **See also** **QKeySequence::keyBindings** ().
        """
        ...

    def setVisible(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#visible-prop

        **visible : bool**

        This property holds whether the action can be seen (e.g. in menus and
        toolbars)

        If **visible** is true the action can be seen (e.g. in menus and
        toolbars) and chosen by the user; if **visible** is false the action
        cannot be seen or chosen by the user.

        Actions which are not visible are **not** grayed out; they do not appear
        at all.

        By default, this property is `true` (actions are visible).

        **Access functions:**

        bool **isVisible** () const
        void **setVisible** (bool)

        **Notifier signal:**

        void **visibleChanged** ()
        """
        ...

    def setDisabled(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#setDisabled

        **[slot] void QAction::setDisabled(bool b )**

        This is a convenience function for the **enabled**  property, that is
        useful for signals--slots connections. If **b** is true the action is
        disabled; otherwise it is enabled.
        """
        ...

    def setEnabled(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#enabled-prop

        **enabled : bool**

        This property holds whether the action is enabled

        Disabled actions cannot be chosen by the user. They do not disappear
        from menus or toolbars, but they are displayed in a way which indicates
        that they are unavailable. For example, they might be displayed using
        only shades of gray.

        **What's This?** help on disabled actions is still available, provided
        that the **QAction::whatsThis**  property is set.

        An action will be disabled when all widgets to which it is added (with
        **QWidget::addAction** ()) are disabled or not visible. When an action
        is disabled, it is not possible to trigger it through its shortcut.

        By default, this property is `true` (actions are enabled).

        **Access functions:**

        bool **isEnabled** () const
        void **setEnabled** (bool)
        void
        **resetEnabled** ()

        **Notifier signal:**

        void **enabledChanged** (bool **enabled** )

        **See also** **text** .
        """
        ...

    def toggle(self) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#toggle

        **[slot] void QAction::toggle()**

        This is a convenience function for the **checked**  property. Connect to
        it to change the checked state to its opposite state.
        """
        ...

    def setChecked(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#checked-prop

        **checked : bool**

        This property holds whether the action is checked.

        Only checkable actions can be checked. By default, this is false (the
        action is unchecked).

        **Note:** The notifier signal for this property is **toggled** (). As
        toggling a **QAction**  changes its state, it will also emit a
        **changed** () signal.

        **Access functions:**

        bool **isChecked** () const
        void **setChecked** (bool)

        **Notifier signal:**

        void ****toggled** ** (bool **checked** )

        **See also** **checkable**  and **toggled** ().
        """
        ...

    def hover(self) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#hover

        **[slot] void QAction::hover()**

        This is a convenience slot that calls activate(Hover).
        """
        ...

    def trigger(self) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#trigger

        **[slot] void QAction::trigger()**

        This is a convenience slot that calls activate(Trigger).
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qaction.html#event

        **[override virtual protected] bool QAction::event(QEvent * e )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    def showStatusText(self, object: typing.Optional[QtCore.QObject] = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qaction.html#showStatusText

        **bool QAction::showStatusText(QObject * object = nullptr)**

        Updates the relevant status bar for the UI represented by **object** by
        sending a **QStatusTipEvent** . Returns `true` if an event was sent,
        otherwise returns `false`.

        If a null widget is specified, the event is sent to the action's parent.

        **See also** **statusTip** .
        """
        ...

    def activate(self, event: "QAction.ActionEvent") -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#activate

        **void QAction::activate(QAction::ActionEvent event )**

        Sends the relevant signals for **ActionEvent**  **event**.

        Action-based widgets use this API to cause the **QAction**  to emit
        signals as well as emitting their own.
        """
        ...

    def isVisible(self) -> bool:
        ...

    def isEnabled(self) -> bool:
        ...

    def isChecked(self) -> bool:
        ...

    def setData(self, var: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#setData

        **void QAction::setData(const QVariant & data )**

        Sets the action's internal data to the given **data**.

        **See also** **data** ().
        """
        ...

    def data(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qaction.html#data

        **QVariant QAction::data() const**

        Returns the user data as set in **QAction::setData** .

        **See also** **setData** ().
        """
        ...

    def isCheckable(self) -> bool:
        ...

    def setCheckable(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#checkable-prop

        **checkable : bool**

        This property holds whether the action is a checkable action

        A checkable action is one which has an on/off state. For example, in a
        word processor, a Bold toolbar button may be either on or off. An action
        which is not a toggle action is a command action; a command action is
        simply executed, e.g. file save. By default, this property is `false`.

        In some situations, the state of one toggle action should depend on the
        state of others. For example, "Left Align", "Center" and "Right Align"
        toggle actions are mutually exclusive. To achieve exclusive toggling,
        add the relevant toggle actions to a **QActionGroup**  with the
        QActionGroup::exclusive property set to true.

        **Access functions:**

        bool **isCheckable** () const
        void **setCheckable** (bool)

        **Notifier signal:**

        void **checkableChanged** (bool **checkable** )

        **See also** **setChecked** ().
        """
        ...

    def font(self) -> "QFont":
        """
        https://doc.qt.io/qt-6/qaction.html#font-prop

        **font : QFont**

        This property holds the action's font

        The font property is used to render the text set on the **QAction** .
        The font can be considered a hint as it will not be consulted in all
        cases based upon application and style.

        By default, this property contains the application's default font.

        **Access functions:**

        QFont **font** () const
        void **setFont** (const QFont & **font** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **setText** ().
        """
        ...

    def setFont(self, font: "QFont") -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#font-prop

        **font : QFont**

        This property holds the action's font

        The font property is used to render the text set on the **QAction** .
        The font can be considered a hint as it will not be consulted in all
        cases based upon application and style.

        By default, this property contains the application's default font.

        **Access functions:**

        QFont **font** () const
        void **setFont** (const QFont & **font** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **setText** ().
        """
        ...

    def shortcutContext(self) -> QtCore.Qt.ShortcutContext:
        """
        https://doc.qt.io/qt-6/qaction.html#shortcutContext-prop

        **shortcutContext : Qt::ShortcutContext**

        This property holds the context for the action's shortcut

        Valid values for this property can be found in **Qt::ShortcutContext** .
        The default value is **Qt::WindowShortcut** .

        **Access functions:**

        Qt::ShortcutContext **shortcutContext** () const
        void
        **setShortcutContext** (Qt::ShortcutContext **context** )

        **Notifier signal:**

        void ****changed** ** ()
        """
        ...

    def setShortcutContext(self, context: QtCore.Qt.ShortcutContext) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#shortcutContext-prop

        **shortcutContext : Qt::ShortcutContext**

        This property holds the context for the action's shortcut

        Valid values for this property can be found in **Qt::ShortcutContext** .
        The default value is **Qt::WindowShortcut** .

        **Access functions:**

        Qt::ShortcutContext **shortcutContext** () const
        void
        **setShortcutContext** (Qt::ShortcutContext **context** )

        **Notifier signal:**

        void ****changed** ** ()
        """
        ...

    def shortcut(self) -> "QKeySequence":
        """
        https://doc.qt.io/qt-6/qaction.html#shortcut

        **QKeySequence QAction::shortcut() const**

        Returns the primary shortcut.

        **Note:** Getter function for property shortcut.

        **See also** **setShortcuts** ().
        """
        ...

    def setShortcut(
        self,
        shortcut: typing.Union["QKeySequence", "QKeySequence.StandardKey", str, int],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#setShortcut

        **void QAction::setShortcut(const QKeySequence & shortcut )**

        Sets **shortcut** as the sole shortcut that triggers the action.

        **Note:** Setter function for property **shortcut** .

        **See also** **shortcut**  and **setShortcuts** ().
        """
        ...

    def isSeparator(self) -> bool:
        """
        https://doc.qt.io/qt-6/qaction.html#isSeparator

        **bool QAction::isSeparator() const**

        Returns `true` if this action is a separator action; otherwise it
        returns `false`.

        **See also** **setSeparator** ().
        """
        ...

    def setSeparator(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#setSeparator

        **void QAction::setSeparator(bool b )**

        If **b** is true then this action will be considered a separator.

        How a separator is represented depends on the widget it is inserted
        into. Under most circumstances the text, submenu, and icon will be
        ignored for separator actions.

        **See also** **isSeparator** ().
        """
        ...

    def whatsThis(self) -> str:
        """
        https://doc.qt.io/qt-6/qaction.html#whatsThis-prop

        **whatsThis : QString**

        This property holds the action's "What's This?" help text

        The "What's This?" text is used to provide a brief description of the
        action. The text may contain rich text. There is no default "What's
        This?" text.

        **Access functions:**

        QString **whatsThis** () const
        void **setWhatsThis** (const QString &
        **what** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **QWhatsThis** .

        **Member Function Documentation**
        """
        ...

    def setWhatsThis(self, what: str) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#whatsThis-prop

        **whatsThis : QString**

        This property holds the action's "What's This?" help text

        The "What's This?" text is used to provide a brief description of the
        action. The text may contain rich text. There is no default "What's
        This?" text.

        **Access functions:**

        QString **whatsThis** () const
        void **setWhatsThis** (const QString &
        **what** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **QWhatsThis** .

        **Member Function Documentation**
        """
        ...

    def statusTip(self) -> str:
        """
        https://doc.qt.io/qt-6/qaction.html#statusTip-prop

        **statusTip : QString**

        This property holds the action's status tip

        The status tip is displayed on all status bars provided by the action's
        top-level parent widget.

        By default, this property contains an empty string.

        **Access functions:**

        QString **statusTip** () const
        void **setStatusTip** (const QString &
        **statusTip** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **setToolTip** () and **showStatusText** ().
        """
        ...

    def setStatusTip(self, statusTip: str) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#statusTip-prop

        **statusTip : QString**

        This property holds the action's status tip

        The status tip is displayed on all status bars provided by the action's
        top-level parent widget.

        By default, this property contains an empty string.

        **Access functions:**

        QString **statusTip** () const
        void **setStatusTip** (const QString &
        **statusTip** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **setToolTip** () and **showStatusText** ().
        """
        ...

    def toolTip(self) -> str:
        """
        https://doc.qt.io/qt-6/qaction.html#toolTip-prop

        **toolTip : QString**

        This property holds the action's tooltip

        This text is used for the tooltip. If no tooltip is specified, the
        action's text is used.

        By default, this property contains the action's text.

        **Access functions:**

        QString **toolTip** () const
        void **setToolTip** (const QString &
        **tip** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **setStatusTip** () and **setShortcut** ().
        """
        ...

    def setToolTip(self, tip: str) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#toolTip-prop

        **toolTip : QString**

        This property holds the action's tooltip

        This text is used for the tooltip. If no tooltip is specified, the
        action's text is used.

        By default, this property contains the action's text.

        **Access functions:**

        QString **toolTip** () const
        void **setToolTip** (const QString &
        **tip** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **setStatusTip** () and **setShortcut** ().
        """
        ...

    def iconText(self) -> str:
        """
        https://doc.qt.io/qt-6/qaction.html#iconText-prop

        **iconText : QString**

        This property holds the action's descriptive icon text

        If **QToolBar::toolButtonStyle**  is set to a value that permits text to
        be displayed, the text defined held in this property appears as a label
        in the relevant tool button.

        It also serves as the default text in menus and tooltips if the action
        has not been defined with **setText** () or **setToolTip** (), and will
        also be used in toolbar buttons if no icon has been defined using
        **setIcon** ().

        If the icon text is not explicitly set, the action's normal text will be
        used for the icon text.

        By default, this property contains an empty string.

        **Access functions:**

        QString **iconText** () const
        void **setIconText** (const QString &
        **text** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **setToolTip** () and **setStatusTip** ().
        """
        ...

    def setIconText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#iconText-prop

        **iconText : QString**

        This property holds the action's descriptive icon text

        If **QToolBar::toolButtonStyle**  is set to a value that permits text to
        be displayed, the text defined held in this property appears as a label
        in the relevant tool button.

        It also serves as the default text in menus and tooltips if the action
        has not been defined with **setText** () or **setToolTip** (), and will
        also be used in toolbar buttons if no icon has been defined using
        **setIcon** ().

        If the icon text is not explicitly set, the action's normal text will be
        used for the icon text.

        By default, this property contains an empty string.

        **Access functions:**

        QString **iconText** () const
        void **setIconText** (const QString &
        **text** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **setToolTip** () and **setStatusTip** ().
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qaction.html#text-prop

        **text : QString**

        This property holds the action's descriptive text

        If the action is added to a menu, the menu option will consist of the
        icon (if there is one), the text, and the shortcut (if there is one). If
        the text is not explicitly set in the constructor, or by using
        setText(), the action's description icon text will be used as text.
        There is no default text.

        **Access functions:**

        QString **text** () const
        void **setText** (const QString & **text** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **iconText** .
        """
        ...

    def setText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#text-prop

        **text : QString**

        This property holds the action's descriptive text

        If the action is added to a menu, the menu option will consist of the
        icon (if there is one), the text, and the shortcut (if there is one). If
        the text is not explicitly set in the constructor, or by using
        setText(), the action's description icon text will be used as text.
        There is no default text.

        **Access functions:**

        QString **text** () const
        void **setText** (const QString & **text** )

        **Notifier signal:**

        void ****changed** ** ()

        **See also** **iconText** .
        """
        ...

    def icon(self) -> "QIcon":
        """
        https://doc.qt.io/qt-6/qaction.html#icon-prop

        **icon : QIcon**

        This property holds the action's icon

        In toolbars, the icon is used as the tool button icon; in menus, it is
        displayed to the left of the menu text. There is no default icon.

        If a null icon (**QIcon::isNull** ()) is passed into this function, the
        icon of the action is cleared.

        **Access functions:**

        QIcon **icon** () const
        void **setIcon** (const QIcon & **icon** )

        **Notifier signal:**

        void ****changed** ** ()
        """
        ...

    def setIcon(self, icon: "QIcon") -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#icon-prop

        **icon : QIcon**

        This property holds the action's icon

        In toolbars, the icon is used as the tool button icon; in menus, it is
        displayed to the left of the menu text. There is no default icon.

        If a null icon (**QIcon::isNull** ()) is passed into this function, the
        icon of the action is cleared.

        **Access functions:**

        QIcon **icon** () const
        void **setIcon** (const QIcon & **icon** )

        **Notifier signal:**

        void ****changed** ** ()
        """
        ...

    def actionGroup(self) -> "QActionGroup":
        """
        https://doc.qt.io/qt-6/qaction.html#actionGroup

        **QActionGroup *QAction::actionGroup() const**

        Returns the action group for this action. If no action group manages
        this action, then `nullptr` will be returned.

        **See also** **QActionGroup**  and **setActionGroup** ().
        """
        ...

    def setActionGroup(self, group: "QActionGroup") -> None:
        """
        https://doc.qt.io/qt-6/qaction.html#setActionGroup

        **void QAction::setActionGroup(QActionGroup * group )**

        Sets this action group to **group**. The action will be automatically
        added to the group's list of actions.

        Actions within the group will be mutually exclusive.

        **See also** **QActionGroup**  and **actionGroup** ().
        """
        ...

    @property
    def changed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaction.html#changed

        **[signal] void QAction::changed()**

        This signal is emitted when an action has changed. If you are only
        interested in actions in a given widget, you can watch for
        **QWidget::actionEvent** () sent with an **QEvent::ActionChanged** .

        **Note:** Notifier signal for property **autoRepeat** . Notifier signal
        for property **font** . Notifier signal for property **icon** . Notifier
        signal for property **iconText** . Notifier signal for property
        **iconVisibleInMenu** . Notifier signal for property **menuRole** .
        Notifier signal for property **shortcut** . Notifier signal for property
        **shortcutContext** . Notifier signal for property
        **shortcutVisibleInContextMenu** . Notifier signal for property
        **statusTip** . Notifier signal for property **text** . Notifier signal
        for property **toolTip** . Notifier signal for property **whatsThis** .

        **See also** **QWidget::actionEvent** ().
        """
        ...

    @property
    def checkableChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def enabledChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def hovered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaction.html#hovered

        **[signal] void QAction::hovered()**

        This signal is emitted when an action is highlighted by the user; for
        example, when the user pauses with the cursor over a menu option,
        toolbar button, or presses an action's shortcut key combination.

        **See also** **activate** ().
        """
        ...

    @property
    def toggled(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaction.html#toggled

        **[signal] void QAction::toggled(bool checked )**

        This signal is emitted whenever a checkable action changes its
        **isChecked** () status. This can be the result of a user interaction,
        or because **setChecked** () was called. As **setChecked** () changes
        the **QAction** , it emits **changed** () in addition to toggled().

        **checked** is true if the action is checked, or false if the action is
        unchecked.

        **Note:** Notifier signal for property **checked** .

        **See also** **activate** (), **triggered** (), and **checked** .
        """
        ...

    @property
    def triggered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaction.html#triggered

        **[signal] void QAction::triggered(bool checked = false)**

        This signal is emitted when an action is activated by the user; for
        example, when the user clicks a menu option, toolbar button, or presses
        an action's shortcut key combination, or when **trigger** () was called.
        Notably, it is **not** emitted when **setChecked** () or **toggle** ()
        is called.

        If the action is checkable, **checked** is true if the action is
        checked, or false if the action is unchecked.

        **See also** **activate** (), **toggled** (), and **checked** .
        """
        ...

    @property
    def visibleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6.QAxContainer import *


class QAxBaseWidget(QtWidgets.QWidget, QAxObjectInterface):
    """
    https://doc.qt.io/qt-6/qaxbasewidget.html

    **Detailed Description**
    """

    def __init__(self) -> None:
        ...

    @property
    def exception(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaxbasewidget.html#exception

        **[signal] void QAxBaseWidget::exception(int code , const QString &
        source , const QString & desc , const QString & help )**

        This signal is emitted when the COM object throws an exception while
        called using the OLE automation interface IDispatch. **code** ,
        **source** , **desc** and **help** provide information about the
        exception as provided by the COM server and can be used to provide
        useful feedback to the end user. **help** includes the help file, and
        the help context ID in brackets, e.g. "filename [id]".

        **See also** **QAxBaseObject::exception** ().
        """
        ...

    @property
    def propertyChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaxbasewidget.html#propertyChanged

        **[signal] void QAxBaseWidget::propertyChanged(const QString & name )**

        If the COM object supports property notification, this signal gets
        emitted when the property called **name** is changed.

        **See also** **QAxBaseObject::propertyChanged** ().
        """
        ...

    @property
    def signal(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaxbasewidget.html#signal

        **[signal] void QAxBaseWidget::signal(const QString & name , int argc ,
        void * argv )**

        This generic signal gets emitted when the COM object issues the event
        **name**. **argc** is the number of parameters provided by the event
        (DISPPARAMS.cArgs), and **argv** is the pointer to the parameter values
        (DISPPARAMS.rgvarg). Note that the order of parameter values is turned
        around, ie. the last element of the array is the first parameter in the
        function.

        void Receiver::slot(const **QString**  &name, int argc, void *argv)
        {
                VARIANTARG *params = (VARIANTARG*)argv;
                if
        (name.startsWith("BeforeNavigate2(")) {
                    IDispatch *pDisp =
        params[argc-1].pdispVal;
                    VARIANTARG URL =
        *params[argc-2].pvarVal;
                    VARIANTARG Flags =
        *params[argc-3].pvarVal;
                    VARIANTARG TargetFrameName =
        *params[argc-4].pvarVal;
                    VARIANTARG PostData =
        *params[argc-5].pvarVal;
                    VARIANTARG Headers =
        *params[argc-6].pvarVal;
                    bool *Cancel =
        params[argc-7].pboolVal;
                }
            }

        Use this signal if the event has parameters of unsupported data types.
        Otherwise, connect directly to the signal **name**.

        **See also** **QAxBaseObject::signal** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtSensors import *


class QAmbientTemperatureReading(QSensorReading):
    """
    https://doc.qt.io/qt-6/qambienttemperaturereading.html

    **Detailed Description**

    The ambient (room) temperature is the temperature in degree Celsius.
    """

    def setTemperature(self, temperature: float) -> None:
        """
        https://doc.qt.io/qt-6/qambienttemperaturereading.html#setTemperature

        **void QAmbientTemperatureReading::setTemperature(qreal temperature )**

        Sets ambient temperature to **temperature**.

        **See also** **temperature** ().
        """
        ...

    def temperature(self) -> float:
        """
        https://doc.qt.io/qt-6/qambienttemperaturereading.html#temperature-prop

        **[read-only] temperature : const qreal**

        This property holds the ambient temperature

        Measured in degree Celsius.

        **Access functions:**

        qreal **temperature** () const

        **Member Function Documentation**
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QPaintEngine(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpaintengine.html

    **Detailed Description**

    Qt provides several premade implementations of QPaintEngine for the
    different painter backends we support. The primary paint engine provided is
    the raster paint engine, which contains a software rasterizer which supports
    the full feature set on all supported platforms. This is the default for
    painting on **QWidget** -based classes in e.g. on Windows, X11 and macOS, it
    is the backend for painting on **QImage**  and it is used as a fallback for
    paint engines that do not support a certain capability. In addition we
    provide QPaintEngine implementations for OpenGL (accessible through
    **QOpenGLWidget** ) and printing (which allows using **QPainter**  to draw
    on a **QPrinter**  object).

    If one wants to use **QPainter**  to draw to a different backend, one must
    subclass QPaintEngine and reimplement all its virtual functions. The
    QPaintEngine implementation is then made available by subclassing
    **QPaintDevice**  and reimplementing the virtual function
    **QPaintDevice::paintEngine** ().

    QPaintEngine is created and owned by the **QPaintDevice**  that created it.

    **See also** **QPainter** , **QPaintDevice::paintEngine** (), and **Paint
    System** .
    """

    class Type(enum.Enum):
        X11: QPaintEngine = ...
        Windows: QPaintEngine = ...
        QuickDraw: QPaintEngine = ...
        CoreGraphics: QPaintEngine = ...
        MacPrinter: QPaintEngine = ...
        QWindowSystem: QPaintEngine = ...
        OpenGL: QPaintEngine = ...
        Picture: QPaintEngine = ...
        SVG: QPaintEngine = ...
        Raster: QPaintEngine = ...
        Direct3D: QPaintEngine = ...
        Pdf: QPaintEngine = ...
        OpenVG: QPaintEngine = ...
        OpenGL2: QPaintEngine = ...
        PaintBuffer: QPaintEngine = ...
        Blitter: QPaintEngine = ...
        Direct2D: QPaintEngine = ...
        User: QPaintEngine = ...
        MaxUser: QPaintEngine = ...

    class PolygonDrawMode(enum.Enum):
        OddEvenMode: QPaintEngine = ...
        WindingMode: QPaintEngine = ...
        ConvexMode: QPaintEngine = ...
        PolylineMode: QPaintEngine = ...

    class DirtyFlag(enum.Flag):
        DirtyPen: QPaintEngine = ...
        DirtyBrush: QPaintEngine = ...
        DirtyBrushOrigin: QPaintEngine = ...
        DirtyFont: QPaintEngine = ...
        DirtyBackground: QPaintEngine = ...
        DirtyBackgroundMode: QPaintEngine = ...
        DirtyTransform: QPaintEngine = ...
        DirtyClipRegion: QPaintEngine = ...
        DirtyClipPath: QPaintEngine = ...
        DirtyHints: QPaintEngine = ...
        DirtyCompositionMode: QPaintEngine = ...
        DirtyClipEnabled: QPaintEngine = ...
        DirtyOpacity: QPaintEngine = ...
        AllDirty: QPaintEngine = ...

    class PaintEngineFeature(enum.Flag):
        PrimitiveTransform: QPaintEngine = ...
        PatternTransform: QPaintEngine = ...
        PixmapTransform: QPaintEngine = ...
        PatternBrush: QPaintEngine = ...
        LinearGradientFill: QPaintEngine = ...
        RadialGradientFill: QPaintEngine = ...
        ConicalGradientFill: QPaintEngine = ...
        AlphaBlend: QPaintEngine = ...
        PorterDuff: QPaintEngine = ...
        PainterPaths: QPaintEngine = ...
        Antialiasing: QPaintEngine = ...
        BrushStroke: QPaintEngine = ...
        ConstantOpacity: QPaintEngine = ...
        MaskedBrush: QPaintEngine = ...
        PaintOutsidePaintEvent: QPaintEngine = ...
        PerspectiveTransform: QPaintEngine = ...
        BlendModes: QPaintEngine = ...
        ObjectBoundingModeGradients: QPaintEngine = ...
        RasterOpModes: QPaintEngine = ...
        AllFeatures: QPaintEngine = ...

    def __init__(self, features: "QPaintEngine.PaintEngineFeature" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#QPaintEngine

        **QPaintEngine::QPaintEngine(QPaintEngine::PaintEngineFeatures caps =
        PaintEngineFeatures())**

        Creates a paint engine with the featureset specified by **caps**.
        """
        ...

    def hasFeature(self, feature: "QPaintEngine.PaintEngineFeature") -> bool:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#hasFeature

        **bool QPaintEngine::hasFeature(QPaintEngine::PaintEngineFeatures
        feature ) const**

        Returns `true` if the paint engine supports the specified **feature** ;
        otherwise returns `false`.
        """
        ...

    def painter(self) -> "QPainter":
        """
        https://doc.qt.io/qt-6/qpaintengine.html#painter

        **QPainter *QPaintEngine::painter() const**

        Returns the paint engine's painter.
        """
        ...

    def type(self) -> "QPaintEngine.Type":
        """
        https://doc.qt.io/qt-6/qpaintengine.html#type

        **[pure virtual] QPaintEngine::Type QPaintEngine::type() const**

        Reimplement this function to return the paint engine **Type** .
        """
        ...

    def paintDevice(self) -> QPaintDevice:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#paintDevice

        **QPaintDevice *QPaintEngine::paintDevice() const**

        Returns the device that this engine is painting on, if painting is
        active; otherwise returns `nullptr`.
        """
        ...

    def setPaintDevice(self, device: QPaintDevice) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#paintDevice

        **QPaintDevice *QPaintEngine::paintDevice() const**

        Returns the device that this engine is painting on, if painting is
        active; otherwise returns `nullptr`.
        """
        ...

    def drawImage(
        self,
        r: QtCore.QRectF,
        pm: QImage,
        sr: QtCore.QRectF,
        flags: QtCore.Qt.ImageConversionFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawImage

        **[virtual] void QPaintEngine::drawImage(const QRectF & rectangle ,
        const QImage & image , const QRectF & sr , Qt::ImageConversionFlags
        flags = Qt::AutoColor)**

        Reimplement this function to draw the part of the **image** specified by
        the **sr** rectangle in the given **rectangle** using the given
        conversion flags **flags** , to convert it to a pixmap.
        """
        ...

    def drawTiledPixmap(
        self, r: QtCore.QRectF, pixmap: QPixmap, s: QtCore.QPointF
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawTiledPixmap

        **[virtual] void QPaintEngine::drawTiledPixmap(const QRectF & rect ,
        const QPixmap & pixmap , const QPointF & p )**

        Reimplement this function to draw the **pixmap** in the given **rect** ,
        starting at the given **p**. The pixmap will be drawn repeatedly until
        the **rect** is filled.
        """
        ...

    def drawTextItem(self, p: QtCore.QPointF, textItem: QTextItem) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawTextItem

        **[virtual] void QPaintEngine::drawTextItem(const QPointF & p , const
        QTextItem & textItem )**

        This function draws the text item **textItem** at position **p**. The
        default implementation of this function converts the text to a
        **QPainterPath**  and paints the resulting path.
        """
        ...

    def drawPixmap(self, r: QtCore.QRectF, pm: QPixmap, sr: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawPixmap

        **[pure virtual] void QPaintEngine::drawPixmap(const QRectF & r , const
        QPixmap & pm , const QRectF & sr )**

        Reimplement this function to draw the part of the **pm** specified by
        the **sr** rectangle in the given **r**.
        """
        ...

    @typing.overload
    def drawPolygon(
        self, points: QtCore.QPointF, mode: "QPaintEngine.PolygonDrawMode"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawPolygon

        **[virtual] void QPaintEngine::drawPolygon(const QPointF * points , int
        pointCount , QPaintEngine::PolygonDrawMode mode )**

        Reimplement this virtual function to draw the polygon defined by the
        **pointCount** first points in **points** , using mode **mode**.

        **Note:** At least one of the drawPolygon() functions must be
        reimplemented.
        """
        ...

    @typing.overload
    def drawPolygon(
        self, points: QtCore.QPoint, mode: "QPaintEngine.PolygonDrawMode"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawPolygon-1

        **[virtual] void QPaintEngine::drawPolygon(const QPoint * points , int
        pointCount , QPaintEngine::PolygonDrawMode mode )**

        This is an overloaded function.

        Reimplement this virtual function to draw the polygon defined by the
        **pointCount** first points in **points** , using mode **mode**.

        **Note:** At least one of the drawPolygon() functions must be
        reimplemented.
        """
        ...

    @typing.overload
    def drawPoints(self, points: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawPoints

        **[virtual] void QPaintEngine::drawPoints(const QPointF * points , int
        pointCount )**

        Draws the first **pointCount** points in the buffer **points**
        """
        ...

    @typing.overload
    def drawPoints(self, points: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawPoints-1

        **[virtual] void QPaintEngine::drawPoints(const QPoint * points , int
        pointCount )**

        Draws the first **pointCount** points in the buffer **points**

        The default implementation converts the first **pointCount** QPoints in
        **points** to QPointFs and calls the floating point version of
        drawPoints.
        """
        ...

    def drawPath(self, path: "QPainterPath") -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawPath

        **[virtual] void QPaintEngine::drawPath(const QPainterPath & path )**

        The default implementation ignores the **path** and does nothing.
        """
        ...

    @typing.overload
    def drawEllipse(self, r: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawEllipse

        **[virtual] void QPaintEngine::drawEllipse(const QRectF & rect )**

        Reimplement this function to draw the largest ellipse that can be
        contained within rectangle **rect**.

        The default implementation calls **drawPolygon** ().
        """
        ...

    @typing.overload
    def drawEllipse(self, r: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawEllipse-1

        **[virtual] void QPaintEngine::drawEllipse(const QRect & rect )**

        The default implementation of this function calls the floating point
        version of this function
        """
        ...

    @typing.overload
    def drawLines(self, lines: QtCore.QLine) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawLines

        **[virtual] void QPaintEngine::drawLines(const QLineF * lines , int
        lineCount )**

        The default implementation splits the list of lines in **lines** into
        **lineCount** separate calls to **drawPath** () or **drawPolygon** ()
        depending on the feature set of the paint engine.
        """
        ...

    @typing.overload
    def drawLines(self, lines: QtCore.QLineF) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawLines-1

        **[virtual] void QPaintEngine::drawLines(const QLine * lines , int
        lineCount )**

        This is an overloaded function.

        The default implementation converts the first **lineCount** lines in
        **lines** to a **QLineF**  and calls the floating point version of this
        function.
        """
        ...

    @typing.overload
    def drawRects(self, rects: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawRects

        **[virtual] void QPaintEngine::drawRects(const QRectF * rects , int
        rectCount )**

        Draws the first **rectCount** rectangles in the buffer **rects**. The
        default implementation of this function calls **drawPath** () or
        **drawPolygon** () depending on the feature set of the paint engine.
        """
        ...

    @typing.overload
    def drawRects(self, rects: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#drawRects-1

        **[virtual] void QPaintEngine::drawRects(const QRect * rects , int
        rectCount )**

        This is an overloaded function.

        The default implementation converts the first **rectCount** rectangles
        in the buffer **rects** to a **QRectF**  and calls the floating point
        version of this function.
        """
        ...

    def updateState(self, state: "QPaintEngineState") -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#updateState

        **[pure virtual] void QPaintEngine::updateState(const QPaintEngineState
        & state )**

        Reimplement this function to update the state of a paint engine.

        When implemented, this function is responsible for checking the paint
        engine's current **state** and update the properties that are changed.
        Use the **QPaintEngineState::state** () function to find out which
        properties that must be updated, then use the corresponding **get
        function**  to retrieve the current values for the given properties.

        **See also** **QPaintEngineState** .
        """
        ...

    def end(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#end

        **[pure virtual] bool QPaintEngine::end()**

        Reimplement this function to finish painting on the current paint
        device. Return true if painting was finished successfully; otherwise
        return false.

        **See also** **begin** () and **isActive** ().
        """
        ...

    def begin(self, pdev: QPaintDevice) -> bool:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#begin

        **[pure virtual] bool QPaintEngine::begin(QPaintDevice * pdev )**

        Reimplement this function to initialise your paint engine when painting
        is to start on the paint device **pdev**. Return true if the
        initialization was successful; otherwise return false.

        **See also** **end** () and **isActive** ().
        """
        ...

    def setActive(self, newState: bool) -> None:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#setActive

        **void QPaintEngine::setActive(bool state )**

        Sets the active state of the paint engine to **state**.

        **See also** **isActive** ().
        """
        ...

    def isActive(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpaintengine.html#isActive

        **bool QPaintEngine::isActive() const**

        Returns `true` if the paint engine is actively drawing; otherwise
        returns `false`.

        **See also** **setActive** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick import *
import enum


class QSGRenderNode(QSGNode):
    """
    https://doc.qt.io/qt-6/qsgrendernode.html

    **Detailed Description**
    """

    class RenderingFlag(enum.Flag):
        BoundedRectRendering: QSGRenderNode = ...
        DepthAwareRendering: QSGRenderNode = ...
        OpaqueRendering: QSGRenderNode = ...

    class StateFlag(enum.Flag):
        DepthState: QSGRenderNode = ...
        StencilState: QSGRenderNode = ...
        ScissorState: QSGRenderNode = ...
        ColorState: QSGRenderNode = ...
        BlendState: QSGRenderNode = ...
        CullState: QSGRenderNode = ...
        ViewportState: QSGRenderNode = ...
        RenderTargetState: QSGRenderNode = ...

    class RenderState(PyQt6.sip.simplewrapper):
        def get(self, state: str) -> PyQt6.sip.voidptr:
            ...

        def clipRegion(self) -> QtGui.QRegion:
            ...

        def stencilEnabled(self) -> bool:
            ...

        def stencilValue(self) -> int:
            ...

        def scissorEnabled(self) -> bool:
            ...

        def scissorRect(self) -> QtCore.QRect:
            ...

        def projectionMatrix(self) -> QtGui.QMatrix4x4:
            ...

    def __init__(self) -> None:
        ...

    def prepare(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgrendernode.html#prepare

        **[virtual, since 6.0] void QSGRenderNode::prepare()**

        Called from the frame preparation phase. There is a call to this
        function before each invocation of **render** ().

        Unlike **render** (), this function is called before the scenegraph
        starts recording the render pass for the current frame on the underlying
        command buffer. This is useful when doing rendering with graphics APIs,
        such as Vulkan, where copy type of operations will need to be recorded
        before the render pass.

        The default implementation is empty.

        This function was introduced in Qt 6.0.
        """
        ...

    def inheritedOpacity(self) -> float:
        """
        https://doc.qt.io/qt-6/qsgrendernode.html#inheritedOpacity

        **qreal QSGRenderNode::inheritedOpacity() const**

        Returns the current effective opacity.
        """
        ...

    def clipList(self) -> QSGClipNode:
        """
        https://doc.qt.io/qt-6/qsgrendernode.html#clipList

        **const QSGClipNode *QSGRenderNode::clipList() const**

        Returns the current clip list.
        """
        ...

    def matrix(self) -> QtGui.QMatrix4x4:
        """
        https://doc.qt.io/qt-6/qsgrendernode.html#matrix

        **const QMatrix4x4 *QSGRenderNode::matrix() const**

        Returns pointer to the current model-view matrix.
        """
        ...

    def rect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qsgrendernode.html#rect

        **[virtual] QRectF QSGRenderNode::rect() const**

        Returns the bounding rectangle in item coordinates for the area
        **render** () touches. The value is only in use when **flags** ()
        includes **BoundedRectRendering** , ignored otherwise.

        Reporting the rectangle in combination with **BoundedRectRendering**  is
        particularly important with the `software` backend because otherwise
        having a rendernode in the scene would trigger fullscreen updates,
        skipping all partial update optimizations.

        For rendernodes covering the entire area of a corresponding
        **QQuickItem**  the return value will be (0, 0, item->width(),
        item->height()).

        **Note:** Nodes are also free to render outside the boundaries specified
        by the item's width and height, since the scenegraph nodes are not
        bounded by the **QQuickItem**  geometry, as long as this is reported
        correctly from this function.

        **See also** **flags** ().
        """
        ...

    def flags(self) -> "QSGRenderNode.RenderingFlag":
        """
        https://doc.qt.io/qt-6/qsgrendernode.html#flags

        **[virtual] QSGRenderNode::RenderingFlags QSGRenderNode::flags() const**

        Returns flags describing the behavior of this render node.

        The default implementation returns 0.

        **See also** **RenderingFlag**  and **rect** ().
        """
        ...

    def releaseResources(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgrendernode.html#releaseResources

        **[virtual] void QSGRenderNode::releaseResources()**

        This function is called when all custom graphics resources allocated by
        this node have to be freed immediately. In case the node does not
        directly allocate graphics resources (buffers, textures, render targets,
        fences, etc.) through the graphics API that is in use, there is nothing
        to do here.

        Failing to release all custom resources can lead to incorrect behavior
        in graphics device loss scenarios on some systems since subsequent
        reinitialization of the graphics system may fail.

        **Note:** Some scenegraph backends may choose not to call this function.
        Therefore it is expected that **QSGRenderNode**  implementations perform
        cleanup both in their destructor and in releaseResources().

        Unlike with the destructor, it is expected that **render** () can
        reinitialize all resources it needs when called after a call to
        releaseResources().

        With OpenGL, the scenegraph's OpenGL context will be current both when
        calling the destructor and this function.
        """
        ...

    def render(self, state: "QSGRenderNode.RenderState") -> None:
        """
        https://doc.qt.io/qt-6/qsgrendernode.html#render

        **[pure virtual] void QSGRenderNode::render(const
        QSGRenderNode::RenderState * state )**

        This function is called by the renderer and should paint this node with
        directly invoking commands in the graphics API (OpenGL, Direct3D, etc.)
        currently in use.

        The effective opacity can be retrieved with **inheritedOpacity** ().

        The projection matrix is available through **state** , while the model-
        view matrix can be fetched with **matrix** (). The combined matrix is
        then the projection matrix times the model-view matrix. The correct
        stacking of the items in the scene is ensured by the projection matrix.

        When using the provided matrices, the coordinate system for vertex data
        follows the usual **QQuickItem**  conventions: top-left is (0, 0),
        bottom-right is the corresponding **QQuickItem** 's width() and height()
        minus one. For example, assuming a two float (x-y) per vertex coordinate
        layout, a triangle covering half of the item can be specified as (width
        - 1, height - 1), (0, 0), (0, height - 1) using counter-clockwise
        direction.

        **Note:****QSGRenderNode**  is provided as a means to implement custom
        2D or 2.5D Qt Quick items. It is not intended for integrating true 3D
        content into the Qt Quick scene. That use case is better supported by
        **QQuickFramebufferObject** , **QQuickWindow::beforeRendering** (), or
        the equivalents of those for APIs other than OpenGL.

        **Note:****QSGRenderNode**  can perform significantly better than
        texture-based approaches (such as, **QQuickFramebufferObject** ),
        especially on systems where the fragment processing power is limited.
        This is because it avoids rendering to a texture and then drawing a
        textured quad. Rather, **QSGRenderNode**  allows recording draw calls in
        line with the scenegraph's other commands, avoiding an additional render
        target and the potentially expensive texturing and blending.

        Clip information is calculated before the function is called.
        Implementations wishing to take clipping into account can set up
        scissoring or stencil based on the information in **state**. The stencil
        buffer is filled with the necessary clip shapes, but it is up to the
        implementation to enable stencil testing.

        Some scenegraph backends, software in particular, use no scissor or
        stencil. There the clip region is provided as an ordinary **QRegion** .

        With the legacy, direct OpenGL based renderer, the following states are
        set on the render thread's context before this function is called:

        * glColorMask(true, true, true, true)
          * glDepthMask(false)
          *
        glDisable(GL_DEPTH_TEST)
          * glStencilFunc(GL_EQUAL, state.stencilValue,
        0xff); glStencilOp(GL_KEEP, GL_KEEP, GL_KEEP) depending on clip
          *
        glScissor(state.scissorRect.x(), state.scissorRect.y(),
        state.scissorRect.width(), state.scissorRect.height()) depending on clip
        * glEnable(GL_BLEND)
          * glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA)
          *
        glDisable(GL_CULL_FACE)

        States that are not listed above, but are covered by **StateFlags** ,
        can have arbitrary values.

        **Note:** There is no state set with other graphics APIs, considering
        that many of them do not have a concept of the traditional OpenGL state
        machine. Rather, it is up to the implementation to create pipeline state
        objects with the desired blending, scissor, and stencil tests enabled.
        Note that this also includes OpenGL via the RHI. New **QSGRenderNode**
        implementations are recommended to set all scissor, stencil and blend
        state explicitly (as shown in the above list), even if they are
        targeting OpenGL.

        **changedStates** () should return which states this function changes.
        If a state is not covered by **StateFlags** , the state should be set to
        the default value according to the OpenGL specification. For other APIs,
        see the documentation for **changedStates** () for more information.

        **Note:** Depth writes are disabled when this function is called
        (glDepthMask(false) with OpenGL). Enabling depth writes can lead to
        unexpected results, depending on the scenegraph backend in use and the
        content in the scene, so exercise caution with this.

        For APIs other than OpenGL, it will likely be necessary to query certain
        API-specific resources (for example, the graphics device or the command
        list/buffer to add the commands to). This is done via
        **QSGRendererInterface** .

        Assume nothing about the pipelines and dynamic states bound on the
        command list/buffer when this function is called.

        With some graphics APIs it can be necessary to also connect to the
        **QQuickWindow::beforeRendering** () signal, because that is emitted
        before recording the beginning of a renderpass on the command buffer
        (vkCmdBeginRenderPass with Vulkan, or starting to encode via
        MTLRenderCommandEncoder in case of Metal). Recording copy operations
        cannot be done inside render() with such APIs. Rather, do it in the slot
        connected (with DirectConnection) to the beforeRendering signal.

        **See also** **QSGRendererInterface**  and
        **QQuickWindow::rendererInterface** ().
        """
        ...

    def changedStates(self) -> "QSGRenderNode.StateFlag":
        """
        https://doc.qt.io/qt-6/qsgrendernode.html#changedStates

        **[virtual] QSGRenderNode::StateFlags QSGRenderNode::changedStates()
        const**

        When the underlying rendering API is OpenGL, this function should return
        a mask where each bit represents graphics states changed by the
        **render** () function:

        * **DepthState**  \\- depth write mask, depth test enabled, depth
        comparison function
          * **StencilState**  \\- stencil write masks,
        stencil test enabled, stencil operations, stencil comparison functions
        * **ScissorState**  \\- scissor enabled, scissor test enabled
          *
        **ColorState**  \\- clear color, color write mask
          * **BlendState**  \\-
        blend enabled, blend function
          * **CullState**  \\- front face, cull
        face enabled
          * **ViewportState**  \\- viewport
          *
        **RenderTargetState**  \\- render target

        With APIs other than OpenGL, the only relevant values are the ones that
        correspond to dynamic state changes recorded on the command list/buffer.
        For example, RSSetViewports, RSSetScissorRects, OMSetBlendState,
        OMSetDepthStencilState in case of D3D11, or vkCmdSetViewport,
        vkCmdSetScissor, vkCmdSetBlendConstants, vkCmdSetStencilRef in case of
        Vulkan, and only when such commands were added to the scenegraph's
        command list queried via the QSGRendererInterface::CommandList resource
        enum. States set in pipeline state objects do not need to be reported
        here. Similarly, draw call related settings (pipeline states, descriptor
        sets, vertex or index buffer bindings, root signature, descriptor heaps,
        etc.) are always set again by the scenegraph so **render** () can freely
        change them.

        **Note:****RenderTargetState**  is no longer supported with APIs like
        Vulkan. This is by nature. **render** () is invoked while the Qt Quick
        scenegraph's main command buffer is recording a renderpass, so there is
        no possibility of changing the target and starting another renderpass
        (on that command buffer at least). Therefore returning a value with
        **RenderTargetState**  set is not sensible.

        The software backend exposes its **QPainter**  and saves and restores
        before and after invoking **render** (). Therefore reporting any changed
        states from here is not necessary.

        The function is called by the renderer so it can reset the states after
        rendering this node. This makes the implementation of **render** ()
        simpler since it does not have to query and restore these states.

        The default implementation returns 0, meaning no relevant state was
        changed in **render** ().

        **Note:** This function may be called before **render** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QUrlQuery(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qurlquery.html

    **Detailed Description**

    It is used to parse the query strings found in URLs like the following:

    ![](images/qurl-querystring.png)

    Query strings like the above are used to transmit options in the URL and are
    usually decoded into multiple key-value pairs. The one above would contain
    two entries in its list, with keys "type" and "color". QUrlQuery can also be
    used to create a query string suitable for use in **QUrl::setQuery** () from
    the individual components of the query.

    The most common way of parsing a query string is to initialize it in the
    constructor by passing it the query string. Otherwise, the **setQuery** ()
    method can be used to set the query to be parsed. That method can also be
    used to parse a query with non-standard delimiters, after having set them
    using the **setQueryDelimiters** () function.

    The encoded query string can be obtained again using **query** (). This will
    take all the internally-stored items and encode the string using the
    delimiters.

    **Encoding**

    All of the getter methods in QUrlQuery support an optional parameter of type
    **QUrl::ComponentFormattingOptions** , including **query** (), which dictate
    how to encode the data in question. Except for **QUrl::FullyDecoded** , the
    returned value must still be considered a percent-encoded string, as there
    are certain values which cannot be expressed in decoded form (like control
    characters, byte sequences not decodable to UTF-8). For that reason, the
    percent character is always represented by the string "%25".

    **Handling of spaces and plus ("+")**

    Web browsers usually encode spaces found in HTML FORM elements to a plus
    sign ("+") and plus signs to its percent-encoded form (%2B). However, the
    Internet specifications governing URLs do not consider spaces and the plus
    character equivalent.

    For that reason, QUrlQuery never encodes the space character to "+" and will
    never decode "+" to a space character. Instead, space characters will be
    rendered "%20" in encoded form.

    To support encoding like that of HTML forms, QUrlQuery also never decodes
    the "%2B" sequence to a plus sign nor encode a plus sign. In fact, any "%2B"
    or "+" sequences found in the keys, values, or query string are left exactly
    like written (except for the uppercasing of "%2b" to "%2B").

    **Full decoding**

    With **QUrl::FullyDecoded**  formatting, all percent-encoded sequences will
    be decoded fully and the '%' character is used to represent itself.
    **QUrl::FullyDecoded**  should be used with care, since it may cause data
    loss. See the documentation of **QUrl::FullyDecoded**  for information on
    what data may be lost.

    This formatting mode should be used only when dealing with text presented to
    the user in contexts where percent-encoding is not desired. Note that
    QUrlQuery setters and query methods do not support the counterpart
    **QUrl::DecodedMode**  parsing, so using **QUrl::FullyDecoded**  to obtain a
    listing of keys may result in keys not found in the object.

    **Non-standard delimiters**

    By default, QUrlQuery uses an equal sign ("=") to separate a key from its
    value, and an ampersand ("&") to separate key-value pairs from each other.
    It is possible to change the delimiters that QUrlQuery uses for parsing and
    for reconstructing the query by calling **setQueryDelimiters** ().

    Non-standard delimiters should be chosen from among what RFC 3986 calls
    "sub-delimiters". They are:

    sub-delims    = "!" / "$" / "&" / "'" / "(" / ")"
                      / "*" /
    "+" / "," / ";" / "="

    Use of other characters is not supported and may result in unexpected
    behaviour. QUrlQuery does not verify that you passed a valid delimiter.

    **See also** **QUrl** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qurlquery.html#QUrlQuery

        **QUrlQuery::QUrlQuery()**

        Constructs an empty QUrlQuery object. A query can be set afterwards by
        calling **setQuery** () or items can be added by using **addQueryItem**
        ().

        **See also** **setQuery** () and **addQueryItem** ().
        """
        ...

    @typing.overload
    def __init__(self, url: QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qurlquery.html#QUrlQuery-1

        **QUrlQuery::QUrlQuery(const QUrl & url )**

        Constructs a QUrlQuery object and parses the query string found in the
        **url** URL, using the default query delimiters. To parse a query string
        using other delimiters, you should first set them using
        **setQueryDelimiters** () and then set the query with **setQuery** ().

        **See also** **QUrl::query** ().
        """
        ...

    @typing.overload
    def __init__(self, queryString: str) -> None:
        """
        https://doc.qt.io/qt-6/qurlquery.html#QUrlQuery-2

        **QUrlQuery::QUrlQuery(const QString & queryString )**

        Constructs a QUrlQuery object and parses the **queryString** query
        string, using the default query delimiters. To parse a query string
        using other delimiters, you should first set them using
        **setQueryDelimiters** () and then set the query with **setQuery** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QUrlQuery") -> None:
        """
        https://doc.qt.io/qt-6/qurlquery.html#QUrlQuery-3

        **[since 5.13] QUrlQuery::QUrlQuery(std::initializer_list<QPair<QString,
        QString> > list )**

        Constructs a QUrlQuery object from the **list** of key/value pair.

        This function was introduced in Qt 5.13.
        """
        ...

    def __hash__(self) -> int:
        ...

    @staticmethod
    def defaultQueryPairDelimiter() -> str:
        """
        https://doc.qt.io/qt-6/qurlquery.html#defaultQueryPairDelimiter

        **[static] char16_t QUrlQuery::defaultQueryPairDelimiter()**

        Returns the default character for separating keys-value pairs from each
        other, an ampersand ("&").

        **Note:** Prior to Qt 6, this function returned **QChar** .

        **See also** **setQueryDelimiters** (), **queryPairDelimiter** (), and
        **defaultQueryValueDelimiter** ().
        """
        ...

    @staticmethod
    def defaultQueryValueDelimiter() -> str:
        """
        https://doc.qt.io/qt-6/qurlquery.html#defaultQueryValueDelimiter

        **[static] char16_t QUrlQuery::defaultQueryValueDelimiter()**

        Returns the default character for separating keys from values in the
        query, an equal sign ("=").

        **Note:** Prior to Qt 6, this function returned **QChar** .

        **See also** **setQueryDelimiters** (), **queryValueDelimiter** (), and
        **defaultQueryPairDelimiter** ().
        """
        ...

    def removeAllQueryItems(self, key: str) -> None:
        """
        https://doc.qt.io/qt-6/qurlquery.html#removeAllQueryItems

        **void QUrlQuery::removeAllQueryItems(const QString & key )**

        Removes all the query string pairs whose key is equal to **key** from
        the URL.

        **See also** **removeQueryItem** ().
        """
        ...

    def allQueryItemValues(
        self, key: str, options: QUrl.ComponentFormattingOption = ...
    ) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qurlquery.html#allQueryItemValues

        **QStringList QUrlQuery::allQueryItemValues(const QString & key ,
        QUrl::ComponentFormattingOptions encoding = QUrl::PrettyDecoded) const**

        Returns the a list of query string values whose key is equal to **key**
        from the URL, using the options specified in **encoding** to encode the
        return value. If the key **key** is not found, this function returns an
        empty list.

        **See also** **queryItemValue** () and **addQueryItem** ().
        """
        ...

    def queryItemValue(
        self, key: str, options: QUrl.ComponentFormattingOption = ...
    ) -> str:
        """
        https://doc.qt.io/qt-6/qurlquery.html#queryItemValue

        **QString QUrlQuery::queryItemValue(const QString & key ,
        QUrl::ComponentFormattingOptions encoding = QUrl::PrettyDecoded) const**

        Returns the query value associated with key **key** from the URL, using
        the options specified in **encoding** to encode the return value. If the
        key **key** is not found, this function returns an empty string. If you
        need to distinguish between an empty value and a non-existent key, you
        should check for the key's presence first using **hasQueryItem** ().

        If the key **key** is multiply defined, this function will return the
        first one found, in the order they were present in the query string or
        added using **addQueryItem** ().

        **See also** **addQueryItem** (), **allQueryItemValues** (), and
        **Encoding** .
        """
        ...

    def removeQueryItem(self, key: str) -> None:
        """
        https://doc.qt.io/qt-6/qurlquery.html#removeQueryItem

        **void QUrlQuery::removeQueryItem(const QString & key )**

        Removes the query string pair whose key is equal to **key** from the
        URL. If there are multiple items with a key equal to **key** , it
        removes the first item in the order they were present in the query
        string or added with **addQueryItem** ().

        **See also** **removeAllQueryItems** ().
        """
        ...

    def addQueryItem(self, key: str, value: str) -> None:
        """
        https://doc.qt.io/qt-6/qurlquery.html#addQueryItem

        **void QUrlQuery::addQueryItem(const QString & key , const QString &
        value )**

        Appends the pair **key** = **value** to the end of the query string of
        the URL. This method does not overwrite existing items that might exist
        with the same key.

        **Note:** This method does not treat spaces (ASCII 0x20) and plus ("+")
        signs as the same, like HTML forms do. If you need spaces to be
        represented as plus signs, use actual plus signs.

        **See also** **hasQueryItem** () and **queryItemValue** ().
        """
        ...

    def hasQueryItem(self, key: str) -> bool:
        """
        https://doc.qt.io/qt-6/qurlquery.html#hasQueryItem

        **bool QUrlQuery::hasQueryItem(const QString & key ) const**

        Returns `true` if there is a query string pair whose key is equal to
        **key** from the URL.

        **See also** **addQueryItem** () and **queryItemValue** ().
        """
        ...

    def queryItems(
        self, options: QUrl.ComponentFormattingOption = ...
    ) -> typing.List[typing.Tuple[str, str]]:
        """
        https://doc.qt.io/qt-6/qurlquery.html#queryItems

        **QList<QPair<QString, QString> >
        QUrlQuery::queryItems(QUrl::ComponentFormattingOptions encoding =
        QUrl::PrettyDecoded) const**

        Returns the query string of the URL, as a map of keys and values, using
        the options specified in **encoding** to encode the items. The order of
        the elements is the same as the one found in the query string or set
        with **setQueryItems** ().

        **See also** **setQueryItems** () and **Encoding** .
        """
        ...

    def setQueryItems(self, query: typing.Iterable[typing.Tuple[str, str]]) -> None:
        """
        https://doc.qt.io/qt-6/qurlquery.html#setQueryItems

        **void QUrlQuery::setQueryItems(const QList<QPair<QString, QString> > &
        query )**

        Sets the items in this **QUrlQuery**  object to **query**. The order of
        the elements in **query** is preserved.

        **Note:** This method does not treat spaces (ASCII 0x20) and plus ("+")
        signs as the same, like HTML forms do. If you need spaces to be
        represented as plus signs, use actual plus signs.

        **See also** **queryItems** () and **isEmpty** ().
        """
        ...

    def queryPairDelimiter(self) -> str:
        """
        https://doc.qt.io/qt-6/qurlquery.html#queryPairDelimiter

        **QChar QUrlQuery::queryPairDelimiter() const**

        Returns the character used to delimit between keys-value pairs when
        reconstructing the query string in **query** () or when parsing in
        **setQuery** ().

        **See also** **setQueryDelimiters** () and **queryValueDelimiter** ().
        """
        ...

    def queryValueDelimiter(self) -> str:
        """
        https://doc.qt.io/qt-6/qurlquery.html#queryValueDelimiter

        **QChar QUrlQuery::queryValueDelimiter() const**

        Returns the character used to delimit between keys and values when
        reconstructing the query string in **query** () or when parsing in
        **setQuery** ().

        **See also** **setQueryDelimiters** () and **queryPairDelimiter** ().
        """
        ...

    def setQueryDelimiters(self, valueDelimiter: str, pairDelimiter: str) -> None:
        """
        https://doc.qt.io/qt-6/qurlquery.html#setQueryDelimiters

        **void QUrlQuery::setQueryDelimiters(QChar valueDelimiter , QChar
        pairDelimiter )**

        Sets the characters used for delimiting between keys and values, and
        between key-value pairs in the URL's query string. The default value
        delimiter is '=' and the default pair delimiter is '&'.

        ![](images/qurl-querystring.png)

        **valueDelimiter** will be used for separating keys from values, and
        **pairDelimiter** will be used to separate key-value pairs. Any
        occurrences of these delimiting characters in the encoded representation
        of the keys and values of the query string are percent encoded when
        returned in **query** ().

        If **valueDelimiter** is set to '(' and **pairDelimiter** is ')', the
        above query string would instead be represented like this:

        http://www.example.com/cgi-bin/drawgraph.cgi?type(pie)color(green)

        **Note:** Non-standard delimiters should be chosen from among what RFC
        3986 calls "sub-delimiters". They are:

        sub-delims    = "!" / "$" / "&" / "'" / "(" / ")"
                          /
        "*" / "+" / "," / ";" / "="

        Use of other characters is not supported and may result in unexpected
        behaviour. This method does not verify that you passed a valid
        delimiter.

        **See also** **queryValueDelimiter** () and **queryPairDelimiter** ().
        """
        ...

    def toString(self, options: QUrl.ComponentFormattingOption = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurlquery.html#toString

        **QString QUrlQuery::toString(QUrl::ComponentFormattingOptions encoding
        = QUrl::PrettyDecoded) const**

        Returns this **QUrlQuery**  as a **QString** . **encoding** can be used
        to specify the URL string encoding of the return value.
        """
        ...

    def setQuery(self, queryString: str) -> None:
        """
        https://doc.qt.io/qt-6/qurlquery.html#setQuery

        **void QUrlQuery::setQuery(const QString & queryString )**

        Parses the query string in **queryString** and sets the internal items
        to the values found there. If any delimiters have been specified with
        **setQueryDelimiters** (), this function will use them instead of the
        default delimiters to parse the string.

        **See also** **query** ().
        """
        ...

    def query(self, options: QUrl.ComponentFormattingOption = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurlquery.html#query

        **QString QUrlQuery::query(QUrl::ComponentFormattingOptions encoding =
        QUrl::PrettyDecoded) const**

        Returns the reconstructed query string, formed from the key-value pairs
        currently stored in this **QUrlQuery**  object and separated by the
        query delimiters chosen for this object. The keys and values are encoded
        using the options given by the **encoding** parameter.

        For this function, the only ambiguous delimiter is the hash ("#"), as in
        URLs it is used to separate the query string from the fragment that may
        follow.

        The order of the key-value pairs in the returned string is exactly the
        same as in the original query.

        **See also** **setQuery** (), **QUrl::setQuery** (), **QUrl::fragment**
        (), and **Encoding** .
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qurlquery.html#clear

        **void QUrlQuery::clear()**

        Clears this **QUrlQuery**  object by removing all of the key-value pairs
        currently stored. If the query delimiters have been changed, this
        function will leave them with their changed values.

        **See also** **isEmpty** () and **setQueryDelimiters** ().
        """
        ...

    def isDetached(self) -> bool:
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qurlquery.html#isEmpty

        **bool QUrlQuery::isEmpty() const**

        Returns `true` if this **QUrlQuery**  object contains no key-value
        pairs, such as after being default-constructed or after parsing an empty
        query string.

        **See also** **setQuery** () and **clear** ().
        """
        ...

    def swap(self, other: "QUrlQuery") -> None:
        """
        https://doc.qt.io/qt-6/qurlquery.html#swap

        **void QUrlQuery::swap(QUrlQuery & other )**

        Swaps this URL query instance with **other**. This function is very fast
        and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtCore
from PyQt6.QtDesigner import *


class QDesignerPropertyEditorInterface(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qdesignerpropertyeditorinterface.html

    **Detailed Description**

    QDesignerPropertyEditorInterface contains a collection of functions that is
    typically used to query the property editor for its current state, and
    several slots manipulating it's state. The interface also provide a signal,
    **propertyChanged** (), which is emitted whenever a property changes in the
    property editor. The signal's arguments are the property that changed and
    its new value.

    For example, when implementing a custom widget plugin, you can connect the
    signal to a custom slot:

    **QDesignerPropertyEditorInterface**  *propertyEditor = 0;
    propertyEditor = formEditor->propertyEditor();
    connect(propertyEditor, SIGNAL(propertyChanged(**QString** ,**QVariant** )),
    this, SLOT(checkProperty(**QString** ,**QVariant** )));

    Then the custom slot can check if the new value is within the range we want
    when a specified property, belonging to a particular widget, changes:

    void checkProperty(**QString**  property, **QVariant**  value) {
    **QDesignerPropertyEditorInterface**  *propertyEditor = 0;
    propertyEditor = formEditor->propertyEditor();
    **QObject**  *object = propertyeditor->object();
    MyCustomWidget *widget = qobject_cast<MyCustomWidget>(object);
    if (widget && property == aProperty && value != expectedValue)
    {...}
                }

    The QDesignerPropertyEditorInterface class is not intended to be
    instantiated directly. You can retrieve an interface to **Qt Designer** 's
    property editor using the **QDesignerFormEditorInterface::propertyEditor**
    () function. A pointer to **Qt Designer** 's current
    **QDesignerFormEditorInterface**  object (`formEditor` in the examples
    above) is provided by the **QDesignerCustomWidgetInterface::initialize** ()
    function's parameter. When implementing a custom widget plugin, you must
    subclass the **QDesignerCustomWidgetInterface**  to expose your plugin to
    **Qt Designer**.

    The functions accessing the property editor are the **core** () function
    that you can use to retrieve an interface to the form editor, the
    **currentPropertyName** () function that returns the name of the currently
    selected property in the property editor, the **object** () function that
    returns the currently selected object in **Qt Designer** 's workspace, and
    the **isReadOnly** () function that returns true if the property editor is
    write proteced (otherwise false).

    The slots manipulating the property editor's state are the **setObject** ()
    slot that you can use to change the currently selected object in **Qt
    Designer** 's workspace, the **setPropertyValue** () slot that changes the
    value of a given property and the **setReadOnly** () slot that control the
    write protection of the property editor.

    **See also** **QDesignerFormEditorInterface** .
    """

    def __init__(
        self, parent: QtWidgets.QWidget, flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerpropertyeditorinterface.html#QDesignerPr
        opertyEditorInterface

        **QDesignerPropertyEditorInterface::QDesignerPropertyEditorInterface(QWi
        dget * parent , Qt::WindowFlags flags = {})**

        Constructs a property editor interface with the given **parent** and the
        specified window **flags**.
        """
        ...

    def setReadOnly(self, readOnly: bool) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerpropertyeditorinterface.html#setReadOnly

        **[pure virtual slot] void
        QDesignerPropertyEditorInterface::setReadOnly(bool readOnly )**

        If **readOnly** is true, the property editor is made write protected;
        otherwise the write protection is removed.

        **See also** **isReadOnly** ().
        """
        ...

    def setPropertyValue(
        self, name: str, value: typing.Any, changed: bool = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerpropertyeditorinterface.html#setProperty
        Value

        **[pure virtual slot] void
        QDesignerPropertyEditorInterface::setPropertyValue(const QString & name
        , const QVariant & value , bool changed = true)**

        Sets the value of the property specified by **name** to **value**.

        In addition, the property is marked as **changed** in the property
        editor, i.e. its value is different from the default value.

        **See also** **currentPropertyName** () and **propertyChanged** ().
        """
        ...

    def setObject(self, object: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerpropertyeditorinterface.html#setObject

        **[pure virtual slot] void
        QDesignerPropertyEditorInterface::setObject(QObject * object )**

        Changes the currently selected object in **Qt Designer** 's workspace,
        to **object**.

        **See also** **object** ().
        """
        ...

    def currentPropertyName(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignerpropertyeditorinterface.html#currentProp
        ertyName

        **[pure virtual] QString
        QDesignerPropertyEditorInterface::currentPropertyName() const**

        Returns the name of the currently selected property in the property
        editor.

        **See also** **setPropertyValue** ().
        """
        ...

    def object(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qdesignerpropertyeditorinterface.html#object

        **[pure virtual] QObject *QDesignerPropertyEditorInterface::object()
        const**

        Returns the currently selected object in **Qt Designer** 's workspace.

        **See also** **setObject** ().
        """
        ...

    def isReadOnly(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerpropertyeditorinterface.html#isReadOnly

        **[pure virtual] bool QDesignerPropertyEditorInterface::isReadOnly()
        const**

        Returns true if the property editor is write protected; otherwise false.

        **See also** **setReadOnly** ().
        """
        ...

    def core(self) -> QDesignerFormEditorInterface:
        """
        https://doc.qt.io/qt-6/qdesignerpropertyeditorinterface.html#core

        **[virtual] QDesignerFormEditorInterface
        *QDesignerPropertyEditorInterface::core() const**

        Returns a pointer to **Qt Designer** 's current
        **QDesignerFormEditorInterface**  object.
        """
        ...

    @property
    def propertyChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerpropertyeditorinterface.html#propertyCha
        nged

        **[signal] void QDesignerPropertyEditorInterface::propertyChanged(const
        QString & name , const QVariant & value )**

        This signal is emitted whenever a property changes in the property
        editor. The property that changed and its new value are specified by
        **name** and **value** respectively.

        **See also** **setPropertyValue** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QWebSocketCorsAuthenticator(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qwebsocketcorsauthenticator.html

    **Detailed Description**

    The QWebSocketCorsAuthenticator class is used in the
    **originAuthenticationRequired** () signal. The class provides a way to pass
    back the required information to the **QWebSocketServer** . It provides
    applications with fine-grained control over which origin URLs are allowed
    and which aren't. By default, every origin is accepted. To get fine-grained
    control, an application connects the **originAuthenticationRequired** ()
    signal to a slot. When the origin (**QWebSocketCorsAuthenticator::origin**
    ()) is accepted, it calls **QWebSocketCorsAuthenticator::setAllowed** (true)

    **Note:** Checking on the origin does not make much sense when the server is
    accessed via a non-browser client, as that client can set whatever origin
    header it likes. In case of a browser client, the server SHOULD check the
    validity of the origin.

    **See also** **WebSocket Security Considerations**  and **QWebSocketServer**
    .
    """

    @typing.overload
    def __init__(self, origin: str) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketcorsauthenticator.html#QWebSocketCorsAu
        thenticator

        **QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(const QString
        & origin )**

        Constructs a new QCorsAuthencator object with the given **origin**.

        **Note:** By default, **allowed** () returns true. This means that per
        default every origin is accepted.
        """
        ...

    @typing.overload
    def __init__(self, other: "QWebSocketCorsAuthenticator") -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketcorsauthenticator.html#QWebSocketCorsAu
        thenticator-1

        **QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(const
        QWebSocketCorsAuthenticator & other )**

        Constructs a copy of **other**.
        """
        ...

    def allowed(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwebsocketcorsauthenticator.html#allowed

        **bool QWebSocketCorsAuthenticator::allowed() const**

        Returns true if the origin is allowed, otherwise returns false.

        **Note:** By default, all origins are accepted.

        **See also** **setAllowed** ().
        """
        ...

    def setAllowed(self, allowed: bool) -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketcorsauthenticator.html#setAllowed

        **void QWebSocketCorsAuthenticator::setAllowed(bool allowed )**

        Allows or disallows the origin. Setting **allowed** to true, will accept
        the connection request for the given origin.

        Setting **allowed** to false, will reject the connection request.

        **Note:** By default, all origins are accepted.

        **See also** **allowed** ().
        """
        ...

    def origin(self) -> str:
        """
        https://doc.qt.io/qt-6/qwebsocketcorsauthenticator.html#origin

        **QString QWebSocketCorsAuthenticator::origin() const**

        Returns the origin this autenticator is handling about.
        """
        ...

    def swap(self, other: "QWebSocketCorsAuthenticator") -> None:
        """
        https://doc.qt.io/qt-6/qwebsocketcorsauthenticator.html#swap

        **void QWebSocketCorsAuthenticator::swap(QWebSocketCorsAuthenticator &
        other )**

        Swaps **other** with this authenticator.

        This operation is very fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtRemoteObjects import *


class QRemoteObjectRegistry(QRemoteObjectReplica):
    """
    https://doc.qt.io/qt-6/qremoteobjectregistry.html

    **Detailed Description**

    The Registry is a special Source/Replica pair held by a **node**  itself. It
    knows about all other **Source** s available on the network, and simplifies
    the process of connecting to other **node** s.
    """

    def sourceLocations(self) -> typing.Dict[str, QRemoteObjectSourceLocationInfo]:
        """
        https://doc.qt.io/qt-6/qremoteobjectregistry.html#sourceLocations

        **QRemoteObjectSourceLocations QRemoteObjectRegistry::sourceLocations()
        const**

        Returns a QRemoteObjectSourceLocations object, which includes the name
        and additional information of all sources known to the registry.

        **Note:** Getter function for property sourceLocations.
        """
        ...

    @property
    def remoteObjectAdded(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qremoteobjectregistry.html#remoteObjectAdded

        **[signal] void QRemoteObjectRegistry::remoteObjectAdded(const
        QRemoteObjectSourceLocation & entry )**

        This signal is emitted whenever a new source location is added to the
        registry.

        **entry** is a QRemoteObjectSourceLocation, a typedef for
        QPair<**QString** , **QUrl** >.

        **See also** **remoteObjectRemoved** ().
        """
        ...

    @property
    def remoteObjectRemoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qremoteobjectregistry.html#remoteObjectRemoved

        **[signal] void QRemoteObjectRegistry::remoteObjectRemoved(const
        QRemoteObjectSourceLocation & entry )**

        This signal is emitted whenever a Source location is removed from the
        Registry.

        **entry** is a QRemoteObjectSourceLocation, a typedef for
        QPair<**QString** , **QUrl** >.

        **See also** **remoteObjectAdded** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QCommandLinkButton(QPushButton):
    """
    https://doc.qt.io/qt-6/qcommandlinkbutton.html

    **Detailed Description**

    The command link is a new control that was introduced by Windows Vista. Its
    intended use is similar to that of a radio button in that it is used to
    choose between a set of mutually exclusive options. Command link buttons
    should not be used by themselves but rather as an alternative to radio
    buttons in Wizards and dialogs and makes pressing the "next" button
    redundant. The appearance is generally similar to that of a flat pushbutton,
    but it allows for a descriptive text in addition to the normal button text.
    By default it will also carry an arrow icon, indicating that pressing the
    control will open another window or page.

    **See also** **QPushButton**  and **QRadioButton** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlinkbutton.html#QCommandLinkButton

        **QCommandLinkButton::QCommandLinkButton(QWidget * parent = nullptr)**

        Constructs a command link with no text and a **parent**.
        """
        ...

    @typing.overload
    def __init__(self, text: str, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlinkbutton.html#QCommandLinkButton-1

        **QCommandLinkButton::QCommandLinkButton(const QString & text , QWidget
        * parent = nullptr)**

        Constructs a command link with the parent **parent** and the text
        **text**.
        """
        ...

    @typing.overload
    def __init__(
        self, text: str, description: str, parent: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlinkbutton.html#QCommandLinkButton-2

        **QCommandLinkButton::QCommandLinkButton(const QString & text , const
        QString & description , QWidget * parent = nullptr)**

        Constructs a command link with a **text** , a **description** , and a
        **parent**.
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlinkbutton.html#paintEvent

        **[override virtual protected] void
        QCommandLinkButton::paintEvent(QPaintEvent *)**

        Reimplements: **QPushButton::paintEvent** (QPaintEvent *).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qcommandlinkbutton.html#event

        **[override virtual protected] bool QCommandLinkButton::event(QEvent * e
        )**

        Reimplements: **QPushButton::event** (QEvent *e).
        """
        ...

    def initStyleOption(self, option: "QStyleOptionButton") -> None:
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qcommandlinkbutton.html#minimumSizeHint

        **[override virtual] QSize QCommandLinkButton::minimumSizeHint() const**

        Reimplements: **QPushButton::minimumSizeHint() const** .
        """
        ...

    def heightForWidth(self, a0: int) -> int:
        """
        https://doc.qt.io/qt-6/qcommandlinkbutton.html#heightForWidth

        **[override virtual] int QCommandLinkButton::heightForWidth(int width )
        const**

        Reimplements: **QWidget::heightForWidth(int w) const** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qcommandlinkbutton.html#sizeHint

        **[override virtual] QSize QCommandLinkButton::sizeHint() const**

        Reimplements: **QPushButton::sizeHint() const** .
        """
        ...

    def setDescription(self, description: str) -> None:
        """
        https://doc.qt.io/qt-6/qcommandlinkbutton.html#description-prop

        **description : QString**

        This property holds a descriptive label to complement the button text

        Setting this property will set a descriptive text on the button,
        complementing the text label. This will usually be displayed in a
        smaller font than the primary text.

        **Access functions:**

        QString **description** () const
        void **setDescription** (const
        QString & **description** )
        """
        ...

    def description(self) -> str:
        """
        https://doc.qt.io/qt-6/qcommandlinkbutton.html#description-prop

        **description : QString**

        This property holds a descriptive label to complement the button text

        Setting this property will set a descriptive text on the button,
        complementing the text label. This will usually be displayed in a
        smaller font than the primary text.

        **Access functions:**

        QString **description** () const
        void **setDescription** (const
        QString & **description** )
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *
import enum


class QImageCapture(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qimagecapture.html

    **Detailed Description**

    The QImageCapture class is a high level images recording class. It's not
    intended to be used alone but for accessing the media recording functions of
    other media objects, like **QCamera** .

    **QMediaCaptureSession**  captureSession;
        camera = new **QCamera** ;
    captureSession.setCamera(camera);

        **QVideoWidget**  *preview = new
    **QVideoWidget** ();
        preview->show();
    captureSession.setVideoOutput(preview);

        imageCapture = new
    **QImageCapture** (camera);
    captureSession.setImageCapture(imageCapture);

        camera->start();
    //on shutter button pressed
        imageCapture->capture();

    **See also** **QCamera** .
    """

    class FileFormat(enum.Enum):
        UnspecifiedFormat: QImageCapture = ...
        JPEG: QImageCapture = ...
        PNG: QImageCapture = ...
        WebP: QImageCapture = ...
        Tiff: QImageCapture = ...

    class Quality(enum.Enum):
        VeryLowQuality: QImageCapture = ...
        LowQuality: QImageCapture = ...
        NormalQuality: QImageCapture = ...
        HighQuality: QImageCapture = ...
        VeryHighQuality: QImageCapture = ...

    class Error(enum.Enum):
        NoError: QImageCapture = ...
        NotReadyError: QImageCapture = ...
        ResourceError: QImageCapture = ...
        OutOfSpaceError: QImageCapture = ...
        NotSupportedFeatureError: QImageCapture = ...
        FormatError: QImageCapture = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#QImageCapture

        **QImageCapture::QImageCapture(QObject * parent = nullptr)**

        Constructs a image capture object, from a **parent** , that can capture
        individual still images produced by a camera.

        You must connect both an image capture object and a **QCamera**  to a
        capture session to capture images.
        """
        ...

    def resolutionChanged(self) -> None:
        ...

    def errorChanged(self) -> None:
        ...

    def capture(self) -> int:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#capture

        **[slot] int QImageCapture::capture()**

        Capture the image and make it available as a **QImage** . This operation
        is asynchronous in majority of cases, followed by signals
        **QImageCapture::imageExposed** (), **QImageCapture::imageCaptured** ()
        or **QImageCapture::error** ().

        QImageCapture::capture returns the capture Id parameter, used with
        **imageExposed** (), **imageCaptured** () and **imageSaved** () signals.

        **See also** **isReadyForCapture** ().
        """
        ...

    def captureToFile(self, location: str = ...) -> int:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#captureToFile

        **[slot] int QImageCapture::captureToFile(const QString & file =
        QString())**

        Capture the image and save it to **file**. This operation is
        asynchronous in majority of cases, followed by signals
        **QImageCapture::imageExposed** (), **QImageCapture::imageCaptured** (),
        **QImageCapture::imageSaved** () or **QImageCapture::error** ().

        If an empty **file** is passed, the camera back end chooses the default
        location and naming scheme for photos on the system, if only file name
        without full path is specified, the image will be saved to the default
        directory, with a full path reported with **imageCaptured** () and
        **imageSaved** () signals.

        **QCamera**  saves all the capture parameters like exposure settings or
        image processing parameters, so changes to camera parameters after
        **capture** () is called do not affect previous capture requests.

        **QImageCapture::capture**  returns the capture Id parameter, used with
        **imageExposed** (), **imageCaptured** () and **imageSaved** () signals.

        **See also** **isReadyForCapture** ().
        """
        ...

    def addMetaData(self, metaData: "QMediaMetaData") -> None:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#addMetaData

        **void QImageCapture::addMetaData(const QMediaMetaData & metaData )**

        Adds additional **metaData** to any existing meta data, that is embedded
        into the captured image.
        """
        ...

    def setMetaData(self, metaData: "QMediaMetaData") -> None:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#setMetaData

        **void QImageCapture::setMetaData(const QMediaMetaData & metaData )**

        Replaces any existing meta data, to be embedded into the captured image,
        with a set of **metaData**.

        **Note:** Setter function for property **metaData** .

        **See also** **metaData** ().
        """
        ...

    def metaData(self) -> "QMediaMetaData":
        """
        https://doc.qt.io/qt-6/qimagecapture.html#metaData-prop

        **metaData : QMediaMetaData**

        This property holds the meta data that will get embedded into the image.

        **Note:** Additional fields such as a time stamp or location may get
        added by the camera back end.

        **Access functions:**

        QMediaMetaData **metaData** () const
        void ****setMetaData** ** (const
        QMediaMetaData & **metaData** )

        **Notifier signal:**

        void **metaDataChanged** ()
        """
        ...

    def setQuality(self, quality: "QImageCapture.Quality") -> None:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#setQuality

        **void QImageCapture::setQuality(QImageCapture::Quality quality )**

        Sets the image encoding **quality**.

        **See also** **quality** ().
        """
        ...

    def quality(self) -> "QImageCapture.Quality":
        """
        https://doc.qt.io/qt-6/qimagecapture.html#quality-prop

        **[read-only] quality : const Quality**

        This property holds the image encoding quality.

        **Access functions:**

        QImageCapture::Quality **quality** () const

        **Notifier signal:**

        void **qualityChanged** ()
        """
        ...

    @typing.overload
    def setResolution(self, a0: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#setResolution

        **void QImageCapture::setResolution(const QSize & resolution )**

        Sets the **resolution** of the encoded image.

        An empty **QSize**  indicates the encoder should make an optimal choice
        based on what is available from the image source and the limitations of
        the codec.

        **See also** **resolution** ().
        """
        ...

    @typing.overload
    def setResolution(self, width: int, height: int) -> None:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#setResolution-1

        **void QImageCapture::setResolution(int width , int height )**

        Sets the **width** and **height** of the resolution of the encoded
        image.

        This is an overloaded function.
        """
        ...

    def resolution(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#resolution

        **QSize QImageCapture::resolution() const**

        Returns the resolution of the encoded image.

        **See also** **setResolution** ().
        """
        ...

    @staticmethod
    def fileFormatDescription(c: "QImageCapture.FileFormat") -> str:
        ...

    @staticmethod
    def fileFormatName(c: "QImageCapture.FileFormat") -> str:
        ...

    @staticmethod
    def supportedFormats() -> typing.List["QImageCapture.FileFormat"]:
        ...

    def setFileFormat(self, format: "QImageCapture.FileFormat") -> None:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#setFileFormat

        **void QImageCapture::setFileFormat(QImageCapture::FileFormat format )**

        Sets the image **format**.

        **See also** **fileFormat** ().
        """
        ...

    def fileFormat(self) -> "QImageCapture.FileFormat":
        """
        https://doc.qt.io/qt-6/qimagecapture.html#fileFormat-prop

        **[read-only] fileFormat : const FileFormat**

        This property holds the image format.

        **Access functions:**

        QImageCapture::FileFormat **fileFormat** () const

        **Notifier signal:**

        void **fileFormatChanged** ()
        """
        ...

    def isReadyForCapture(self) -> bool:
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#errorString

        **QString QImageCapture::errorString() const**

        Returns a string describing the current error state.

        **Note:** Getter function for property errorString.

        **See also** **error** ().
        """
        ...

    def error(self) -> "QImageCapture.Error":
        """
        https://doc.qt.io/qt-6/qimagecapture.html#error

        **QImageCapture::Error QImageCapture::error() const**

        Returns the current error state.

        **Note:** Getter function for property error.

        **See also** **errorString** ().
        """
        ...

    def captureSession(self) -> "QMediaCaptureSession":
        """
        https://doc.qt.io/qt-6/qimagecapture.html#captureSession

        **QMediaCaptureSession *QImageCapture::captureSession() const**

        Returns the capture session this camera is connected to, or a nullptr if
        the camera is not connected to a capture session.

        Use **QMediaCaptureSession::setImageCapture** () to connect the image
        capture to a session.
        """
        ...

    def isAvailable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#isAvailable

        **bool QImageCapture::isAvailable() const**

        Returns true if the images capture service ready to use.
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#errorOccurred

        **[signal] void QImageCapture::errorOccurred(int id ,
        QImageCapture::Error error , const QString & errorString )**

        Signals that the capture request **id** has failed with an **error** and
        **errorString** description.
        """
        ...

    @property
    def fileFormatChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def imageAvailable(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#imageAvailable

        **[signal] void QImageCapture::imageAvailable(int id , const QVideoFrame
        & frame )**

        Signal emitted when QImageCapture::CaptureToBuffer is set and the
        **frame** with request **id** is available.
        """
        ...

    @property
    def imageCaptured(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#imageCaptured

        **[signal] void QImageCapture::imageCaptured(int id , const QImage &
        preview )**

        Signal emitted when the frame with request **id** was captured, but not
        processed and saved yet. Frame **preview** can be displayed to user.
        """
        ...

    @property
    def imageExposed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#imageExposed

        **[signal] void QImageCapture::imageExposed(int id )**

        Signal emitted when the frame with request **id** was exposed.
        """
        ...

    @property
    def imageSaved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#imageSaved

        **[signal] void QImageCapture::imageSaved(int id , const QString &
        fileName )**

        Signal emitted when QImageCapture::CaptureToFile is set and the frame
        with request **id** was saved to **fileName**.
        """
        ...

    @property
    def metaDataChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def qualityChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def readyForCaptureChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qimagecapture.html#readyForCaptureChanged

        **[signal] void QImageCapture::readyForCaptureChanged(bool ready )**

        Signals that a camera's **ready** for capture state has changed.

        **Note:** Notifier signal for property **readyForCapture** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QSplitterHandle(QWidget):
    """
    https://doc.qt.io/qt-6/qsplitterhandle.html

    **Detailed Description**

    QSplitterHandle is typically what people think about when they think about a
    splitter. It is the handle that is used to resize the widgets.

    A typical developer using **QSplitter**  will never have to worry about
    QSplitterHandle. It is provided for developers who want splitter handles
    that provide extra features, such as popup menus.

    The typical way one would create splitter handles is to subclass
    **QSplitter**  and then reimplement **QSplitter::createHandle** () to
    instantiate the custom splitter handle. For example, a minimum **QSplitter**
    subclass might look like this:

    class Splitter : public **QSplitter**
        {
        public:
    Splitter(Qt::Orientation orientation, **QWidget**  *parent = nullptr);
    protected:
            **QSplitterHandle**  *createHandle() override;
        };

    The **createHandle** () implementation simply constructs a custom splitter
    handle, called `Splitter` in this example:

    **QSplitterHandle**  *Splitter::createHandle()
        {
            return new
    SplitterHandle(orientation(), this);
        }

    Information about a given handle can be obtained using functions like
    **orientation** () and **opaqueResize** (), and is retrieved from its parent
    splitter. Details like these can be used to give custom handles different
    appearances depending on the splitter's orientation.

    The complexity of a custom handle subclass depends on the tasks that it
    needs to perform. A simple subclass might only provide a **paintEvent** ()
    implementation:

    void SplitterHandle::paintEvent(**QPaintEvent**  *event)
        {
    **QPainter**  painter(this);
            if (orientation() == Qt::Horizontal) {
    gradient.setStart(rect().left(), rect().height()/2);
    gradient.setFinalStop(rect().right(), rect().height()/2);
            } else {
    gradient.setStart(rect().width()/2, rect().top());
    gradient.setFinalStop(rect().width()/2, rect().bottom());
            }
    painter.fillRect(event->rect(), **QBrush** (gradient));
        }

    In this example, a predefined gradient is set up differently depending on
    the orientation of the handle. QSplitterHandle provides a reasonable size
    hint for the handle, so the subclass does not need to provide a
    reimplementation of **sizeHint** () unless the handle has special size
    requirements.

    **See also** **QSplitter** .
    """

    def __init__(self, o: QtCore.Qt.Orientation, parent: QSplitter) -> None:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#QSplitterHandle

        **QSplitterHandle::QSplitterHandle(Qt::Orientation orientation ,
        QSplitter * parent )**

        Creates a **QSplitter**  handle with the given **orientation** and
        **parent**.
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#resizeEvent

        **[override virtual protected] void
        QSplitterHandle::resizeEvent(QResizeEvent * event )**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).
        """
        ...

    def closestLegalPosition(self, p: int) -> int:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#closestLegalPosition

        **[protected] int QSplitterHandle::closestLegalPosition(int pos )**

        Returns the closest legal position to **pos** of the splitter handle.
        The positions are measured from the left or top edge of the splitter,
        even for right-to-left languages.

        **See also** **QSplitter::closestLegalPosition** () and **moveSplitter**
        ().
        """
        ...

    def moveSplitter(self, p: int) -> None:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#moveSplitter

        **[protected] void QSplitterHandle::moveSplitter(int pos )**

        Tells the splitter to move this handle to position **pos** , which is
        the distance from the left or top edge of the widget.

        Note that **pos** is also measured from the left (or top) for right-to-
        left languages. This function will map **pos** to the appropriate
        position before calling **QSplitter::moveSplitter** ().

        **See also** **QSplitter::moveSplitter** () and **closestLegalPosition**
        ().
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#event

        **[override virtual protected] bool QSplitterHandle::event(QEvent *
        event )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def mouseReleaseEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#mouseReleaseEvent

        **[override virtual protected] void
        QSplitterHandle::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#mousePressEvent

        **[override virtual protected] void
        QSplitterHandle::mousePressEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def mouseMoveEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#mouseMoveEvent

        **[override virtual protected] void
        QSplitterHandle::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#paintEvent

        **[override virtual protected] void
        QSplitterHandle::paintEvent(QPaintEvent *)**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#sizeHint

        **[override virtual] QSize QSplitterHandle::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...

    def splitter(self) -> QSplitter:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#splitter

        **QSplitter *QSplitterHandle::splitter() const**

        Returns the splitter associated with this splitter handle.

        **See also** **QSplitter::handle** ().
        """
        ...

    def opaqueResize(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#opaqueResize

        **bool QSplitterHandle::opaqueResize() const**

        Returns `true` if widgets are resized dynamically (opaquely) while
        interactively moving the splitter. Otherwise returns `false`. This value
        is controlled by the **QSplitter** .

        **See also** **QSplitter::opaqueResize** ().
        """
        ...

    def orientation(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#orientation

        **Qt::Orientation QSplitterHandle::orientation() const**

        Returns the handle's orientation. This is usually propagated from the
        **QSplitter** .

        **See also** **setOrientation** () and **QSplitter::orientation** ().
        """
        ...

    def setOrientation(self, o: QtCore.Qt.Orientation) -> None:
        """
        https://doc.qt.io/qt-6/qsplitterhandle.html#setOrientation

        **void QSplitterHandle::setOrientation(Qt::Orientation orientation )**

        Sets the orientation of the splitter handle to **orientation**. This is
        usually propagated from the **QSplitter** .

        **See also** **orientation** () and **QSplitter::setOrientation** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip


class QAbstractOpenGLFunctions(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qabstractopenglfunctions.html

    **Detailed Description**

    OpenGL implementations on different platforms are able to link to a variable
    number of OpenGL functions depending upon the OpenGL ABI on that platform.
    For example, on Microsoft Windows only functions up to those in OpenGL 1.1
    can be linked to at build time. All other functions must be resolved at
    runtime. The traditional solution to this has been to use either
    **QOpenGLContext::getProcAddress** () or **QOpenGLFunctions** . The former
    is tedious and error prone and means dealing directly with function
    pointers. The latter only exposes those functions common to OpenGL ES 2 and
    desktop OpenGL. There is however much new OpenGL functionality that is
    useful when writing real world OpenGL applications.

    Qt now provides a family of classes which all inherit from
    QAbstractOpenGLFunctions which expose every core OpenGL function by way of a
    corresponding member function. There is a class for every valid combination
    of OpenGL version and profile. Each class follows the naming convention:

    QOpenGLFunctions_<MAJOR VERSION>_<MINOR VERSION>[_PROFILE]

    For OpenGL versions 1.0 through to 3.0 there are no profiles, leading to the
    classes:

    * **QOpenGLFunctions_1_0**
      * **QOpenGLFunctions_1_1**
      *
    **QOpenGLFunctions_1_2**
      * **QOpenGLFunctions_1_3**
      *
    **QOpenGLFunctions_1_4**
      * **QOpenGLFunctions_1_5**
      *
    **QOpenGLFunctions_2_0**
      * **QOpenGLFunctions_2_1**
      *
    **QOpenGLFunctions_3_0**

    where each class inherits from QAbstractOpenGLFunctions.

    OpenGL version 3.1 removed many deprecated functions leading to a much
    simpler and generic API.

    With OpenGL 3.2 the concept of profiles was introduced. Two profiles are
    currently defined for OpenGL: Core and Compatibility.

    The Core profile does not include any of the functions that were removed in
    OpenGL 3.1. The Compatibility profile contains all functions in the Core
    profile of the same version plus all of the functions that were removed in
    OpenGL 3.1. In this way the Compatibility profile classes allow use of newer
    OpenGL functionality but also allows you to keep using your legacy OpenGL
    code. For new OpenGL code the Core profile should be preferred.

    Please note that some vendors, notably Apple, do not implement the
    Compatibility profile. Therefore if you wish to target new OpenGL features
    on macOS then you should ensure that you request a Core profile context via
    **QSurfaceFormat::setProfile** ().

    Qt provides classes for all version and Core and Compatibility profile
    combinations. The classes for OpenGL versions 3.1 through to 4.3 are:

    * **QOpenGLFunctions_3_1**
      * **QOpenGLFunctions_3_2_Core**
      *
    **QOpenGLFunctions_3_2_Compatibility**
      * **QOpenGLFunctions_3_3_Core**
    * **QOpenGLFunctions_3_3_Compatibility**
      * **QOpenGLFunctions_4_0_Core**
    * **QOpenGLFunctions_4_0_Compatibility**
      * **QOpenGLFunctions_4_1_Core**
    * **QOpenGLFunctions_4_1_Compatibility**
      * **QOpenGLFunctions_4_2_Core**
    * **QOpenGLFunctions_4_2_Compatibility**
      * **QOpenGLFunctions_4_3_Core**
    * **QOpenGLFunctions_4_3_Compatibility**

    where each class inherits from QAbstractOpenGLFunctions.

    A pointer to an object of the class corresponding to the version and profile
    of OpenGL in use can be obtained from
    **QOpenGLVersionFunctionsFactory::get** (). If obtained in this way, note
    that the **QOpenGLContext**  retains ownership of the object. This is so
    that the instance can be cached and shared.

    Before calling any of the exposed OpenGL functions you must ensure that the
    object has resolved the function pointers to the OpenGL functions. This only
    needs to be done once per instance with initializeOpenGLFunctions(). Once
    initialized, the object can be used to call any OpenGL function for the
    corresponding version and profile. Note that initializeOpenGLFunctions() can
    fail in some circumstances so check the return value. Situations in which
    initialization can fail are if you have a functions object for a version or
    profile that contains functions that are not part of the context being used
    to resolve the function pointers.

    If you exclusively use function objects then you will get compile time
    errors if you attempt to use a function not included in that version and
    profile. This is obviously a lot easier to debug than undefined behavior at
    run time.

    **See also** **QOpenGLVersionFunctionsFactory::get** ().
    """

    ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QAbstractFileIconProvider(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qabstractfileiconprovider.html

    **Detailed Description**
    """

    class Option(enum.Flag):
        DontUseCustomDirectoryIcons: QAbstractFileIconProvider = ...

    class IconType(enum.Enum):
        Computer: QAbstractFileIconProvider = ...
        Desktop: QAbstractFileIconProvider = ...
        Trashcan: QAbstractFileIconProvider = ...
        Network: QAbstractFileIconProvider = ...
        Drive: QAbstractFileIconProvider = ...
        Folder: QAbstractFileIconProvider = ...
        File: QAbstractFileIconProvider = ...

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractfileiconprovider.html#QAbstractFileIconP
        rovider

        **QAbstractFileIconProvider::QAbstractFileIconProvider()**

        Constructs a file icon provider.
        """
        ...

    def options(self) -> "QAbstractFileIconProvider.Option":
        """
        https://doc.qt.io/qt-6/qabstractfileiconprovider.html#options

        **[virtual] QAbstractFileIconProvider::Options
        QAbstractFileIconProvider::options() const**

        Returns all the options that affect the icon provider. By default, all
        options are disabled.

        **See also** **setOptions** ().
        """
        ...

    def setOptions(self, a0: "QAbstractFileIconProvider.Option") -> None:
        """
        https://doc.qt.io/qt-6/qabstractfileiconprovider.html#setOptions

        **[virtual] void
        QAbstractFileIconProvider::setOptions(QAbstractFileIconProvider::Options
        options )**

        Sets **options** that affect the icon provider.

        **See also** **options** ().
        """
        ...

    def type(self, a0: QtCore.QFileInfo) -> str:
        """
        https://doc.qt.io/qt-6/qabstractfileiconprovider.html#type

        **[virtual] QString QAbstractFileIconProvider::type(const QFileInfo &
        info ) const**

        Returns the type of the file described by **info**.
        """
        ...

    @typing.overload
    def icon(self, a0: "QAbstractFileIconProvider.IconType") -> "QIcon":
        """
        https://doc.qt.io/qt-6/qabstractfileiconprovider.html#icon

        **[virtual] QIcon
        QAbstractFileIconProvider::icon(QAbstractFileIconProvider::IconType type
        ) const**

        Returns an icon set for the given **type** , using the current icon
        theme.

        **See also** **QIcon::fromTheme** .
        """
        ...

    @typing.overload
    def icon(self, a0: QtCore.QFileInfo) -> "QIcon":
        """
        https://doc.qt.io/qt-6/qabstractfileiconprovider.html#icon-1

        **[virtual] QIcon QAbstractFileIconProvider::icon(const QFileInfo & info
        ) const**

        Returns an icon for the file described by **info** , using the current
        icon theme.

        **See also** **QIcon::fromTheme** .
        """
        ...
